"use strict";
var nftAbi = null,
    nftContract = null,
    tokenId = null,
    marketplaceAbi = null,
    marketplaceContract = null,
    userWallet = null,
    routes = {
        base: "",
        mint: "",
        burn: "",
        list: "",
        unlist: "",
        purchase: "",
        bid: "",
        updateBid: ""
    },
    csrfToken = $('meta[name="csrf-token"]').attr('content'),
    handleError = (error) => {
        var message = error?.message ?? error?.data?.message;

        if (error.code == 4001) {
            notify('error', 'The request was rejected by the user')
        } else if (error.code == -32602) {
            notify('error', 'The parameters were invalid')
        } else if (error.code == -32603) {
            message || notify('error', 'Internal error')
        } else {
            console.error(error);
        }

        if (message) notify('error', 'Metamask: '.message);
        reloadNow(5000);
    },
    checkSigner = async (signer) => {
        let signerAddress = await signer.getAddress(),
            matched = signerAddress == userWallet;
        (matched) || notify('error', 'Please connect and select valid wallet');
        (matched) || reloadNow(5000);
        return matched;
    },
    reloadNow = (sleepTime = 2000) => {
        setTimeout(() => {
            window.location.reload(true)
        }, sleepTime);
    };
$(document).ready(function () {
    $.getJSON(`${routes.base}/assets/contracts/nft/abi.json`, function (abi) {
        nftAbi = abi;
    });
    $.getJSON(`${routes.base}/assets/contracts/marketplace/abi.json`, function (abi) {
        marketplaceAbi = abi;
    });
});

const NFT = {
    mint: async (uri, categoryId, fileType) => {
        const provider = new ethers.providers.Web3Provider(window.ethereum)
        await provider.send("eth_requestAccounts", []);
        const signer = provider.getSigner();
        if (!nftContract || !(await checkSigner(signer))) {
            notify('error', 'Something is wrong. Please try again later.');
            return;
        }
        const NFT_CONTRACT = new ethers.Contract(nftContract, nftAbi, signer);
        const nftData = await (await NFT_CONTRACT.mint(uri).catch(handleError)).wait();
        var id = await NFT_CONTRACT.tokenCount();
        tokenId = parseInt(id._hex, 16);
        if (tokenId) {
            setInterval(() => {
                notify('warning', `Please don\'t reload or close window.`);
                notify('info', `Please wait, minting process is still running.`);
            }, 18000);
            $.ajax({
                headers: {
                    'X-CSRF-TOKEN': csrfToken
                },
                url: routes.mint,
                method: "POST",
                data: {
                    ifps_uri: uri,
                    token_id: tokenId,
                    category_id: categoryId,
                    file_type: fileType,
                    transaction_hash: nftData.transactionHash
                },
                success: function (response) {
                    let notification = `Failed to mint. Please try again.`;
                    let type = 'error';
                    if (response) {
                        notification = `NFT Minted`;
                        type = `success`;
                    }
                    notify(type, notification);
                    reloadNow();
                }
            }).done(function () {
                setTimeout(function () {
                    $("#overlay, #overlay2").fadeOut(300);
                }, 500);
            });
        }
    },
    burn: async (tokenId, nftId, callback) => {
        const provider = new ethers.providers.Web3Provider(window.ethereum)
        await provider.send("eth_requestAccounts", []);
        const signer = provider.getSigner();
        if (!(await checkSigner(signer))) return;
        const NFT_CONTRACT = new ethers.Contract(nftContract, nftAbi, signer);
        await (await NFT_CONTRACT.burn(tokenId).catch(handleError)).wait();
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': csrfToken
            },
            url: `${routes.burn}/${nftId}`,
            method: "POST",
            data: {},
            success: function (response) {
                (typeof callback === "function") && callback(response);
            }
        });
    },
    list: async (tokenId, nftId, amount, auctionDateTimeInUnix, callback) => {
        let amountInWei = ethers.utils.parseUnits(`${amount}`, "ether");
        const provider = new ethers.providers.Web3Provider(window.ethereum)
        await provider.send("eth_requestAccounts", []);
        const signer = provider.getSigner();
        if (!(await checkSigner(signer))) return;
        const nft = new ethers.Contract(nftContract, nftAbi, signer);
        await (await nft.approve(marketplaceContract, tokenId).catch(handleError)).wait();

        const marketplace = new ethers.Contract(marketplaceContract, marketplaceAbi, signer);
        await (await marketplace.makeItem(nftContract, tokenId, amountInWei, auctionDateTimeInUnix).catch(handleError)).wait();
        var itemCount = await marketplace.itemCount();
        // var items = await marketplace.items(parseInt(itemCount._hex, 16));


        $.ajax({
            headers: {
                'X-CSRF-TOKEN': csrfToken
            },
            url: routes.list,
            method: "POST",
            data: {
                nftId: nftId,
                itemId: parseInt(itemCount._hex, 16),
                amount: amount,
                auctionDateTimeInUnix: auctionDateTimeInUnix
            },
            success: function (response) {
                (typeof callback === "function") && callback(response);
            }
        });
    },
    unlist: async (itemId, callback) => {
        const provider = new ethers.providers.Web3Provider(window.ethereum)
        await provider.send("eth_requestAccounts", []);
        const signer = provider.getSigner();
        if (!(await checkSigner(signer))) return;
        const marketplace = new ethers.Contract(marketplaceContract, marketplaceAbi, signer);
        await (await marketplace.unlistItem(itemId).catch(handleError)).wait();
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': csrfToken
            },
            url: `${routes.unlist}/${itemId}`,
            method: "POST",
            data: {},
            success: function (response) {
                (typeof callback === "function") && callback(response);
            }
        });
    },
    purchase: async (itemId, fromBalance, callback) => {
        let priceJson = {
            value: 0
        };

        const provider = new ethers.providers.Web3Provider(window.ethereum)
        await provider.send("eth_requestAccounts", []);
        const signer = provider.getSigner();
        if (!(await checkSigner(signer))) return;
        const marketplace = new ethers.Contract(marketplaceContract, marketplaceAbi, signer);
        if (!fromBalance) {
            var totalPrice = await marketplace.getItemPrice(itemId);
            totalPrice = parseInt(totalPrice._hex, 16);
            priceJson = {
                value: ethers.utils.parseUnits(`${totalPrice}`, "wei")
            };
        }
        const purchasedData = await (await marketplace.purchaseItem(itemId, fromBalance, priceJson).catch(handleError)).wait();
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': csrfToken
            },
            url: `${routes.purchase}/${itemId}`,
            method: "POST",
            data: {
                transactionHash: purchasedData.transactionHash
            },
            success: function (response) {
                (typeof callback === "function") && callback(response);
            }
        });
    },
    bid: async (itemId, fromBalance, bidAmount, callback) => {

        let bidAmountInWei = ethers.utils.parseUnits(`${bidAmount}`, "ether");
        let priceJson = {
            value: 0
        };
        const provider = new ethers.providers.Web3Provider(window.ethereum)
        await provider.send("eth_requestAccounts", []);
        const signer = provider.getSigner();
        if (!(await checkSigner(signer))) return;
        const marketplace = new ethers.Contract(marketplaceContract, marketplaceAbi, signer);
        if (!fromBalance) {
            priceJson = {
                value: bidAmountInWei
            };
        }
        await (await marketplace.bidItem(itemId, fromBalance, fromBalance ? bidAmountInWei : 0, priceJson).catch(handleError)).wait();
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': csrfToken
            },
            url: `${routes.bid}/${itemId}`,
            method: "POST",
            data: {
                amount: bidAmount
            },
            success: function (response) {
                (typeof callback === "function") && callback(response);
            }
        });
    },
    updateBid: async (itemId, fromBalance, bidAmount, callback) => {

        let bidAmountInWei = ethers.utils.parseUnits(`${bidAmount}`, "ether");
        let priceJson = {
            value: 0
        };
        const provider = new ethers.providers.Web3Provider(window.ethereum)
        await provider.send("eth_requestAccounts", []);
        const signer = provider.getSigner();
        if (!(await checkSigner(signer))) return;
        const marketplace = new ethers.Contract(marketplaceContract, marketplaceAbi, signer);
        if (!fromBalance) {
            priceJson = {
                value: bidAmountInWei
            };
        }
        await (await marketplace.updateBid(itemId, fromBalance, fromBalance ? bidAmountInWei : 0, priceJson).catch(handleError)).wait();
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': csrfToken
            },
            url: `${routes.updateBid}/${itemId}`,
            method: "POST",
            data: {
                amount: bidAmount
            },
            success: function (response) {
                (typeof callback === "function") && callback(response);
            }
        });
    },
    claim: async (itemId, claimTo, callback) => {
        const provider = new ethers.providers.Web3Provider(window.ethereum)
        await provider.send("eth_requestAccounts", []);
        const signer = provider.getSigner();
        if (!(await checkSigner(signer))) return;
        const marketplace = new ethers.Contract(marketplaceContract, marketplaceAbi, signer);
        await (await marketplace.claimBidAmount(itemId, claimTo).catch(handleError)).wait();
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': csrfToken
            },
            url: `${routes.claim}/${itemId}`,
            method: "POST",
            data: {},
            success: function (response) {
                (typeof callback === "function") && callback(response);
            }
        });
    }
}