<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Bid;
use App\Models\Contract;
use App\Models\Deposit;
use App\Models\Item;
use App\Models\Nft;
use App\Models\NftActivity;
use App\Models\NftView;
use App\Models\Wishlist;
use App\Models\Withdrawal;
use Illuminate\Http\Request;
use stdClass;

class ContractController extends Controller
{
    public function index()
    {
        $pageTitle   = 'Contract Setting';
        $contracts   = Contract::latest()->get();
        $marketplace = $contracts->where('act', 'marketplace')->first();
        $nft         = $contracts->where('act', 'nft')->first();

        return view('admin.setting.contracts', compact('marketplace', 'nft', 'pageTitle'));
    }
    public function storeMarketplace(Request $request)
    {
        $marketplace = Contract::marketplace()->latest()->first();
        if ($marketplace->contract) {
            $response = [
                'type'    => 'error',
                'message' => 'You have already deployed a contract.',
            ];
        } else {
            $params = $this->getParameterData($marketplace, $request->form_data);
            if ($params) {
                $marketplace->contract   = $request->contract;
                $marketplace->txhash     = $request->txhash;
                $marketplace->parameters = $params;
                $marketplace->save();
                $response = [
                    'type'    => 'success',
                    'message' => 'Contract deployed successfully',
                ];
            } else {
                $response = [
                    'type'    => 'error',
                    'message' => 'Please provide valid data.',
                ];
            }

        }
        return response()->json($response);
    }
    public function getParameterData($contract, $formData = null, $withData = true)
    {
        $marketplaceParameters = new stdClass();
        foreach ($contract->parameters as $key => $value) {
            $marketplaceParameters->$key        = $value;
            $marketplaceParameters->$key->value = array_reduce($formData ?? [], function ($carry, $item) use ($key) {
                return $item["name"] == $key ? $item["value"] : $carry;
            });
            if ($withData && !$marketplaceParameters->$key->value) {
                $marketplaceParameters = null;
                break;
            }
        }
        return $marketplaceParameters;
    }
    public function destroyMarketplace(Request $request)
    {
        $marketplace             = Contract::marketplace()->latest()->first();
        $marketplace->contract   = '';
        $marketplace->txhash     = '';
        $marketplace->parameters = $this->getParameterData($marketplace, null, false);
        $marketplace->save();

        $nft             = Contract::nft()->latest()->first();
        $nft->contract   = '';
        $nft->txhash     = '';
        $nft->parameters = $this->getParameterData($nft, null, false);
        $nft->save();

        Deposit::truncate();
        Withdrawal::truncate();

        Bid::truncate();
        Item::truncate();
        Nft::truncate();
        NftActivity::truncate();
        Wishlist::truncate();

        $notify[] = ['success', 'Marketplace contract destroyed successfully'];
        return back()->withNotify($notify);
    }
    public function storeNft(Request $request)
    {
        $marketplace = Contract::marketplace()->latest()->first();
        $nft         = Contract::nft()->latest()->first();
        if (!@$marketplace->contract) {
            $response = [
                'type'    => 'error',
                'message' => 'Please deploy marketplace contract first.',
            ];
        } else if ($nft->contract) {
            $response = [
                'type'    => 'error',
                'message' => 'You have already deployed a contract.',
            ];
        } else {
            $params = $this->getParameterData($nft, $request->form_data);
            if ($params) {
                $nft->contract   = $request->contract;
                $nft->txhash     = $request->txhash;
                $nft->parameters = $params;
                $nft->save();
                $response = [
                    'type'    => 'success',
                    'message' => 'Contract deployed successfully',
                ];
            } else {
                $response = [
                    'type'    => 'error',
                    'message' => 'Please provide valid data.',
                ];
            }
        }
        return response()->json($response);
    }
    public function destroyNft()
    {
        $nft           = Contract::nft()->latest()->first();
        $nft->contract = '';
        $nft->txhash   = '';
        $nft->save();
        Bid::truncate();
        Item::truncate();
        Nft::truncate();
        NftActivity::truncate();
        NftView::truncate();
        Wishlist::truncate();
        $notify[] = ['success', 'Nft contract destroyed successfully'];
        return back()->withNotify($notify);
    }
}
