<?php

namespace App\Http\Controllers\Admin;

use App\Models\Item;
use App\Models\Report;
use App\Models\Contract;
use App\Constants\Status;
use App\Http\Controllers\Controller;

class ManageItemController extends Controller
{
    public function listed()
    {
        return $this->itemData('listed');
    }

    public function sell()
    {
        return $this->itemData('sell');
    }

    public function auction()
    {
        return $this->itemData('auction');
    }
    
    public function expiredAuctions()
    {
        return $this->itemData('expiredAuction');
    }

    private function itemData($scope)
    {
        $pageTitle   = ucwords(preg_replace('/(?<=\\w)(?=[A-Z])/', ' $1', $scope)) . ' Items';
        $items       = Item::$scope()->searchable(['nft:name', 'user:wallet'])->with('nft.category')->orderBy('id', 'desc')->paginate(getPaginate());
        $marketplace = Contract::marketplace()->first();

        return view('admin.item.list', compact('pageTitle', 'items', 'marketplace'));
    }

    public function detail($id)
    {
        $pageTitle     = 'Item Details';
        $item          = Item::with('nft.category', 'bids.user')->findOrFail($id);
        $nft           = $item->nft;
        $nftActivities = $nft->nftActivities()->orderBy('id', 'desc')->paginate(getPaginate());

        return view('admin.nft.detail', compact('pageTitle', 'nft', 'nftActivities', 'item'));
    }

    public function report($id)
    {
        $item      = Item::findOrFail($id);
        $pageTitle = 'Report of "' . $item->nft->name . '"';
        $reports   = Report::with('user')->where('item_id', $id)->paginate(getPaginate());
        return view('admin.report_quote', compact('pageTitle', 'reports'));
    }

    public function feature($id)
    {
        $item              = Item::listed()->findOrFail($id);
        $item->is_featured = !$item->is_featured;
        $item->save();

        $notification = $item->is_featured ? 'Item featured successfully' : 'Item unfeatured successfully';

        $notify[] = ['success', $notification];
        return back()->withNotify($notify);
    }

    public function sendWinnerMail($itemId)
    {
        $item = Item::with(['nft', 'bids' => function ($bid) {
            $bid->with('user')->orderBy('amount', 'desc');
        }])->where('itemId', $itemId)->first();

        $item->status = Status::ITEM_SOLD;
        $item->save();

        $item->bids->count();

        if ($item->bids->count()) {
            $winnerBid = $item->bids[0];

            notify($item->user, 'WINNER_ITEM_OWNER', [
                'nft_name'      => $item->nft->name,
                'winner_wallet' => $winnerBid->user->username ?? showAddress($winnerBid->user->wallet),
                'bid_amount'    => showAmount($winnerBid->amount),
                'currency'      => marketplaceCurrency(),
            ]);

            notify($winnerBid->user, 'ITEM_WINNER', [
                'nft_name'   => $item->nft->name,
                'bid_amount' => showAmount($winnerBid->amount),
                'total_bid'  => $item->bids->count(),
                'currency'   => marketplaceCurrency(),
            ]);
        }

        if ($item->bids->count() > 1) {
            $loserBids = $item->bids->skip(1);

            foreach ($loserBids as $loserBid) {
                notify($loserBid->user, 'ITEM_LOSER', [
                    'nft_name'   => $item->nft->name,
                    'bid_amount' => showAmount($loserBid->amount),
                    'winner_bid' => showAmount($winnerBid->amount),
                    'total_bid'  => $item->bids->count(),
                    'currency'   => marketplaceCurrency(),
                ]);
            }

        }
    }

}
