<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Nft;
use App\Models\NftSize;
use Illuminate\Http\Request;

class ManageNftController extends Controller
{
    public function all()
    {
        $pageTitle = 'All Nft';
        $nfts      = $this->nftData();
        return view('admin.nft.list', compact('pageTitle', 'nfts'));
    }

    public function active()
    {
        $pageTitle = 'Active Nft';
        $nfts      = $this->nftData('active');
        return view('admin.nft.list', compact('pageTitle', 'nfts'));
    }

    public function listed()
    {
        $pageTitle = 'Listed Nft';
        $nfts      = $this->nftData('listed');
        return view('admin.nft.list', compact('pageTitle', 'nfts'));
    }

    public function burned()
    {
        $pageTitle = 'Burned Nft';
        $nfts      = $this->nftData('burned');
        return view('admin.nft.list', compact('pageTitle', 'nfts'));
    }

    private function nftData($scope = null)
    {
        if ($scope) {
            $nfts = Nft::$scope();
        } else {
            $nfts = Nft::query();
        }

        return $nfts->searchable(['name', 'user:wallet'])->with('category')->orderBy('id', 'desc')->paginate(getPaginate());
    }

    public function detail($id)
    {
        $pageTitle     = 'Nft Details';
        $nft           = Nft::with('category')->findOrFail($id);
        $nftActivities = $nft->nftActivities()->orderBy('id', 'desc')->paginate(getPaginate());

        return view('admin.nft.detail', compact('pageTitle', 'nft', 'nftActivities'));
    }

    public function sizeLimit()
    {
        $pageTitle = 'Nft Size Limit';
        $nftSizes  = NftSize::searchable(['file_type', 'file_extension'])->orderBy('file_type')->paginate(getPaginate());
        return view('admin.nft.size_limit', compact('pageTitle', 'nftSizes'));
    }

    public function updateSizeLimit(Request $request, $id)
    {
        $request->validate([
            'max_size' => 'required|integer|min:1',
        ]);

        $nftSize           = NftSize::findOrFail($id);
        $nftSize->max_size = $request->max_size;
        $nftSize->save();

        $notify[] = ['success', strtoupper($nftSize->file_extension) . " nft max size updated successfully"];
        return back()->withNotify($notify);
    }

}
