<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Bid;
use App\Models\Nft;
use Carbon\Carbon;
use Illuminate\Http\Request;

class NftStatisticsController extends Controller
{
    public function nftStatistics()
    {
        $pageTitle = 'Nft Statistics';

        $widget['today_bid_count']     = Bid::whereDate('created_at', today())->count();
        $widget['this_week_bid_count'] = Bid::where('created_at', '>=', now()->startOfWeek())->count();
        $widget['this_year_bid_count'] = Bid::where('created_at', '>=', now()->startOfYear())->count();
        $widget['all_time_bid_count']  = Bid::count();

        $widget['yesterday_bid_count'] = Bid::whereDate('created_at', Carbon::yesterday())->count();
        $widget['last_week_bid_count'] = Bid::where(dateRangeQuery('created_at', 'last_week'))->count();
        $widget['last_year_bid_count'] = Bid::where(dateRangeQuery('created_at', 'last_year'))->count();

        $widget['today_nft_mint']     = Nft::whereDate('created_at', today())->count();
        $widget['this_week_nft_mint'] = Nft::where('created_at', '>=', now()->startOfWeek())->count();
        $widget['this_year_nft_mint'] = Nft::where('created_at', '>=', now()->startOfYear())->count();
        $widget['all_time_nft_mint']  = Nft::count();

        $widget['yesterday_nft_mint'] = Nft::whereDate('created_at', Carbon::yesterday())->count();
        $widget['last_week_nft_mint'] = Nft::where(dateRangeQuery('created_at', 'last_week'))->count();
        $widget['last_year_nft_mint'] = Nft::where(dateRangeQuery('created_at', 'last_year'))->count();

        $widget['today_nft_burn']     = Nft::burned()->whereDate('updated_at', today())->count();
        $widget['this_week_nft_burn'] = Nft::burned()->where('updated_at', '>=', now()->startOfWeek())->count();
        $widget['this_year_nft_burn'] = Nft::burned()->where('updated_at', '>=', now()->startOfYear())->count();
        $widget['all_time_nft_burn']  = Nft::burned()->count();

        $widget['yesterday_nft_burn'] = Nft::burned()->whereDate('updated_at', Carbon::yesterday())->count();
        $widget['last_week_nft_burn'] = Nft::burned()->where(dateRangeQuery('updated_at', 'last_week'))->count();
        $widget['last_year_nft_burn'] = Nft::burned()->where(dateRangeQuery('updated_at', 'last_year'))->count();

        return view('admin.nft_statistics.index', compact('pageTitle', 'widget'));
    }

    public function loadStatistics(Request $request)
    {
        if ($request->time == 'week') {
            $time     = now()->startOfWeek();
            $prevTime = now()->startOfWeek()->subWeek();
        } elseif ($request->time == 'month') {
            $time     = now()->startOfMonth();
            $prevTime = now()->startOfMonth()->subMonth();
        } else {
            $time     = now()->startOfYear();
            $prevTime = now()->startOfYear()->subYear();
        }

        if ($request->graph == 'bid') {
            $model     = app("App\\Models\\Bid");
            $items     = $model::query();
            $sumColumn = 'amount';
        } elseif ($request->graph == 'purchase') {
            $model     = app("App\\Models\\NftActivity");
            $items     = $model::query()->where('type', 'purchased');
            $sumColumn = 'amount';
        } else {
            $model = app("App\\Models\\NftView");
            $items = $model::query();

            $sumColumn = 'views';
        }

        if ($request->time == 'week' || $request->time == 'month') {
            $items->selectRaw("SUM($sumColumn) as amount, DATE_FORMAT(created_at, '%d-%M-%Y') as date")->groupBy('date');
        } else {
            $items->selectRaw("SUM($sumColumn) as amount, DATE_FORMAT(created_at, '%M-%Y') as date")->groupBy('date');
        }

        $items      = $items->where('created_at', '>=', $time)->get();
        $totalValue = $items->sum('amount');

        $items = $items->mapWithKeys(function ($item) {
            return [
                $item->date => (float) $item->amount,
            ];
        });

        $prevValue = $model::where('created_at', '>=', $prevTime)->where('created_at', '<', $time)->sum("$sumColumn");

        $valueDiff = ($prevValue ? $totalValue / $prevValue * 100 - 100 : 0);
        $upDown    = $valueDiff > 0 ? 'up' : 'down';
        $valueDiff = abs($valueDiff);

        return [
            'data'        => $items,
            'total_value' => $totalValue,
            'value_diff'  => round($valueDiff, 2),
            'up_down'     => $upDown,
        ];
    }

}
