<?php

namespace App\Http\Controllers;

use App\Constants\Status;
use App\Models\Category;
use App\Models\Follower;
use App\Models\Frontend;
use App\Models\Item;
use App\Models\Language;
use App\Models\Nft;
use App\Models\Page;
use App\Models\Subscriber;
use App\Models\User;
use App\Models\Wishlist;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cookie;
use Illuminate\Support\Facades\Validator;

class SiteController extends Controller
{
    public function index()
    {
        $reference = @$_GET['reference'];
        if ($reference) {
            session()->put('reference', $reference);
        }

        $pageTitle = 'Home';
        $sections = Page::where('tempname', activeTemplate())->where('slug', '/')->first();
        $seoContents = $sections->seo_content;
        $seoImage = @$seoContents->image ? getImage(getFilePath('seo') . '/' . @$seoContents->image, getFileSize('seo')) : null;
        return view('Template::home', compact('pageTitle', 'sections', 'seoContents', 'seoImage'));
    }

    public function pages($slug)
    {
        $page = Page::where('tempname', activeTemplate())->where('slug', $slug)->firstOrFail();
        $pageTitle = $page->name;
        $sections = $page->secs;
        $seoContents = $page->seo_content;
        $seoImage = @$seoContents->image ? getImage(getFilePath('seo') . '/' . @$seoContents->image, getFileSize('seo')) : null;
        return view('Template::pages', compact('pageTitle', 'sections', 'seoContents', 'seoImage'));
    }


    public function policyPages($slug)
    {
        $policy = Frontend::where('slug', $slug)->where('data_keys', 'policy_pages.element')->firstOrFail();
        $pageTitle = $policy->data_values->title;
        $seoContents = $policy->seo_content;
        $seoImage = @$seoContents->image ? frontendImage('policy_pages', $seoContents->image, getFileSize('seo'), true) : null;
        return view('Template::policy', compact('policy', 'pageTitle', 'seoContents', 'seoImage'));
    }

    public function changeLanguage($lang = null)
    {
        $language = Language::where('code', $lang)->first();
        if (!$language) $lang = 'en';
        session()->put('lang', $lang);
        return back();
    }


    public function blogs()
    {
        $blogs     = Frontend::where('data_keys', 'blog.element')->orderBy('id', 'desc')->paginate(getPaginate());
        $pageTitle = 'Blogs';
        $page      = Page::where('tempname', activeTemplate())->where('slug', 'blogs')->first();
        $sections  = $page->secs;
        return view('Template::blogs', compact('blogs', 'pageTitle', 'sections'));
    }

    public function blogDetails($slug)
    {
        $blog = Frontend::where('slug', $slug)->where('data_keys', 'blog.element')->firstOrFail();
        $blogs     = Frontend::where('slug', '!=', $slug)->where('data_keys', 'blog.element')->latest()->limit(5)->get();

        $pageTitle = $blog->data_values->title;
        $seoContents = $blog->seo_content;
        $seoImage = @$seoContents->image ? frontendImage('blog', $seoContents->image, getFileSize('seo'), true) : null;
        return view('Template::blog_details', compact('blog', 'pageTitle', 'seoContents', 'seoImage', 'blogs'));
    }


    public function cookieAccept()
    {
        Cookie::queue('gdpr_cookie', gs('site_name'), 43200);
    }

    public function cookiePolicy()
    {
        $cookieContent = Frontend::where('data_keys', 'cookie.data')->first();
        abort_if($cookieContent->data_values->status != Status::ENABLE, 404);
        $pageTitle = 'Cookie Policy';
        $cookie = Frontend::where('data_keys', 'cookie.data')->first();
        return view('Template::cookie', compact('pageTitle', 'cookie'));
    }

    public function placeholderImage($size = null)
    {
        $imgWidth = explode('x', $size)[0];
        $imgHeight = explode('x', $size)[1];
        $text = $imgWidth . '×' . $imgHeight;
        $fontFile = realpath('assets/font/solaimanLipi_bold.ttf');
        $fontSize = round(($imgWidth - 50) / 8);
        if ($fontSize <= 9) {
            $fontSize = 9;
        }
        if ($imgHeight < 100 && $fontSize > 30) {
            $fontSize = 30;
        }

        $image     = imagecreatetruecolor($imgWidth, $imgHeight);
        $colorFill = imagecolorallocate($image, 100, 100, 100);
        $bgFill    = imagecolorallocate($image, 255, 255, 255);
        imagefill($image, 0, 0, $bgFill);
        $textBox = imagettfbbox($fontSize, 0, $fontFile, $text);
        $textWidth  = abs($textBox[4] - $textBox[0]);
        $textHeight = abs($textBox[5] - $textBox[1]);
        $textX      = ($imgWidth - $textWidth) / 2;
        $textY      = ($imgHeight + $textHeight) / 2;
        header('Content-Type: image/jpeg');
        imagettftext($image, $fontSize, 0, $textX, $textY, $colorFill, $fontFile, $text);
        imagejpeg($image);
        imagedestroy($image);
    }

    public function maintenance()
    {
        $pageTitle = 'Maintenance Mode';
        if (gs('maintenance_mode') == Status::DISABLE) {
            return to_route('home');
        }
        $maintenance = Frontend::where('data_keys', 'maintenance.data')->first();
        return view('Template::maintenance', compact('pageTitle', 'maintenance'));
    }
    public function publicProfile(Request $request, $wallet)
    {
        $user = User::where('wallet', $wallet)->firstOrFail();
        $nfts = Nft::where('user_id', $user->id)->where('status', '!=', Status::NFT_BURNED);

        if ($request->name) {
            $nfts->where('name', 'LIKE', "%$request->name%");
        }

        if ($request->category) {
            $nfts->where('category_id', $request->category);
        }

        $nfts = $nfts->whereHas('category', function ($category) {
            $category->active();
        })->orderBy('id', 'desc')->paginate(getPaginate());

        $categories = Category::active()->get();
        $pageTitle  = $user->firstname ? $user->fullname . ' Profile' : 'Unnamed Profile';

        $seoContents['keywords']           = [];
        $seoContents['social_title']       = $user->firstname ? $user->fullname : showAddress($user->wallet);
        $seoContents['description']        = '';
        $seoContents['social_description'] = '';
        $seoContents['image']              = getImage(getFilePath('userProfile') . '/' . $user->image, avatar: 'profile');
        $seoContents['image_size']         = getFileSize('userProfile');

        return view('Template::public_profile.index', compact('pageTitle', 'user', 'nfts', 'categories', 'seoContents'));
    }
    public function profileFollowList($wallet, $follow)
    {
        abort_if(!in_array($follow, ['following', 'follower']), 404);
        $pageTitle = ucFirst($follow) . ' List';
        $user      = User::where('wallet', $wallet)->firstOrFail();

        $myFollowingIds = [];
        $myFollowingIds = Follower::where('follower_id', auth()->id())->pluck('user_id')->toArray();

        $followList = Follower::query();

        if ($follow == 'follower') {
            $followList->with('followerUser')->where('user_id', $user->id);
            $view = 'follower';
        } else {
            $followList->with('followingUser')->where('follower_id', $user->id);
            $view = 'following';
        }

        $followList = $followList->get();

        return view("Template::public_profile.$view", compact('pageTitle', 'user', 'followList', 'myFollowingIds'));
    }
    public function subscribe(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email|unique:subscribers,email',
        ], [
            'email.unique' => 'This email has already been subscribed',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'code'    => 200,
                'status'  => 'error',
                'message' => $validator->errors()->all(),
            ]);
        }

        $subscribe        = new Subscriber();
        $subscribe->email = $request->email;
        $subscribe->save();

        $notify = 'Thank you, we\'ll notice you our latest news';

        return response()->json([
            'code'    => 200,
            'status'  => 'success',
            'message' => $notify,
        ]);
    }
    public function wishlist(Request $request)
    {
        if (!auth()->check()) {
            return response()->json(['message' => 'You must be login before item add to your wishlist.']);
        }

        $validator = Validator::make($request->all(), [
            'item_id' => 'required|integer',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'status'  => 'error',
                'message' => $validator->errors()->all(),
            ]);
        }

        $item = Item::listed()->where('id', $request->item_id)->first();

        if (!$item) {
            return response()->json(['message' => 'Item not found']);
        }

        $wishlist = Wishlist::where('item_id', $request->item_id)->where('user_id', auth()->id())->first();

        if ($wishlist) {
            $item = $wishlist->item;
            $item->wishlist_count -= 1;
            $item->save();

            $wishlist->delete();
            $notification = 'Item removed from your wishlist successfully';
            $isAdded      = -1;
        } else {
            $wishlist          = new Wishlist();
            $wishlist->user_id = auth()->id();
            $wishlist->item_id = $request->item_id;
            $wishlist->save();

            $item = $wishlist->item;
            $item->wishlist_count += 1;
            $item->save();

            $notification = 'Item added to your wishlist successfully';
            $isAdded      = 1;
        }

        return response()->json(['status' => 'success', 'is_added' => $isAdded, 'message' => $notification]);
    }
    public function follow(Request $request)
    {
        if (!auth()->check()) {
            return response()->json(['message' => 'You must be login before following to someone.']);
        }

        $validator = Validator::make($request->all(), [
            'user_id' => 'required|integer',
        ]);

        if ($validator->fails()) {
            return response()->json([
                'status'  => 'error',
                'message' => $validator->errors()->all(),
            ]);
        }

        $targetedUser = User::find($request->user_id);
        $user         = auth()->user();

        if (!$targetedUser) {
            return response()->json(['message' => 'User not found']);
        }

        if ($targetedUser->id == $user->id) {
            return response()->json(['message' => 'You can\'t follow yourself']);
        }

        $follower = Follower::where('user_id', $targetedUser->id)->where('follower_id', $user->id)->first();

        if ($follower) {
            $follower->delete();
            $notification = 'Creator removed from your following list';
            $targetedUser->follower_count -= 1;
            $user->following_count -= 1;
            $isAdded = -1;
        } else {
            $follower              = new Follower();
            $follower->user_id     = $request->user_id;
            $follower->follower_id = $user->id;
            $follower->save();
            $targetedUser->follower_count += 1;
            $user->following_count += 1;
            $notification = 'Creator added to your following list';
            $isAdded      = 1;
        }

        $targetedUser->save();
        $user->save();

        return response()->json(['status' => 'success', 'is_added' => $isAdded, 'message' => $notification]);
    }
}
