<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Models\Contract;
use App\Models\Deposit;
use App\Models\Withdrawal;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class AccountController extends Controller
{
    public function depositHistory(Request $request)
    {
        $pageTitle = 'Deposit History';
        $deposits  = auth()->user()->deposits()->searchable(['trx'])->orderBy('id', 'desc')->paginate(getPaginate());
        return view('Template::user.deposit_history', compact('pageTitle', 'deposits'));
    }

    public function saveDeposit(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'transaction_hash' => 'required',
            'amount'           => 'required|numeric|gt:0',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $deposit                   = new Deposit();
        $deposit->user_id          = auth()->id();
        $deposit->transaction_hash = $request->transaction_hash;
        $deposit->amount           = $request->amount;
        $deposit->method_currency  = marketplaceCurrency();
        $deposit->final_amo        = $request->amount;
        $deposit->save();

        notify(auth()->user(), 'DEPOSIT_COMPLETE', [
            'currency'         => marketplaceCurrency(),
            'amount'           => showAmount($deposit->amount),
            'transaction_hash' => showAddress($deposit->transaction_hash),
            'transaction_hash_url' => blockExplorer() . '/tx/' . $deposit->transaction_hash,
        ]);

        return response()->json(['status' => 'success', 'message' => 'Deposit success']);
    }

    public function withdrawHistory(Request $request)
    {
        $pageTitle = "Withdraw Log";
        $withdraws = Withdrawal::where('user_id', auth()->id());

        if ($request->search) {
            $withdraws = $withdraws->where('trx', $request->search);
        }

        $withdraws = $withdraws->orderBy('id', 'desc')->paginate(getPaginate());

        return view('Template::user.withdraw_history', compact('pageTitle', 'withdraws'));
    }

    public function saveWithdraw(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'transaction_hash' => 'required',
            'amount'           => 'required|numeric|gt:0',
        ]);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()]);
        }

        $withdraw                   = new Withdrawal();
        $withdraw->user_id          = auth()->id();
        $withdraw->transaction_hash = $request->transaction_hash;
        $withdraw->amount           = $request->amount;
        $withdraw->currency         = marketplaceCurrency();
        $withdraw->final_amount     = $request->amount;
        $withdraw->save();

        notify(auth()->user(), 'WITHDRAW_COMPLETE', [
            'currency'         => marketplaceCurrency(),
            'amount'           => showAmount($withdraw->amount),
            'transaction_hash' => showAddress($withdraw->transaction_hash),
            'transaction_hash_url' => blockExplorer() . '/tx/' . $withdraw->transaction_hash,
        ]);

        return response()->json(['status' => 'success', 'message' => 'Withdraw success']);
    }
}
