<?php

namespace App\Models;

use App\Constants\Status;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Model;

class Item extends Model
{
    protected $casts = ['auction_end_at' => 'integer'];

    public function nft()
    {
        return $this->belongsTo(Nft::class);
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }

    public function bids()
    {
        return $this->hasMany(Bid::class);
    }

    public function wishlists()
    {
        return $this->hasMany(Wishlist::class);
    }

    public function scopeListed($query)
    {
        $query->where('status', Status::ITEM_LISTED);
    }

    public function scopeUnlisted($query)
    {
        $query->where('status', Status::ITEM_UNLISTED);
    }

    public function scopeSold($query)
    {
        $query->where('status', Status::ITEM_SOLD);
    }

    public function scopeSell($query)
    {
        $query->listed()->where('is_auction', Status::NO);
    }

    public function scopeAuction($query)
    {
        $query->listed()->where('is_auction', Status::YES);
    }
    public function scopeExpiredAuction($query)
    {
        $query->listed()->where('is_auction', Status::YES)->where('auction_end_at', '<', now()->timestamp);
    }

    public function scopeFeatured($query)
    {
        $query->where('status', Status::ITEM_LISTED)->where('is_featured', Status::YES);
    }

    public function statusBadge(): Attribute
    {
        return new Attribute(function () {
            $html = '';
            if ($this->status == Status::ITEM_UNLISTED) {
                $html = '<span class="badge badge--warning">' . trans('Unlisted') . '</span>';
            } elseif ($this->status == Status::ITEM_LISTED) {
                $html = '<span class="badge badge--success">' . trans('Listed') . '</span>';
            } else {
                $html = '<span class="badge badge--primary">' . trans('Sold') . '</span>';
            }
            return $html;
        });
    }

    public function featuredBadge(): Attribute
    {
        return new Attribute(function () {
            $html = '';
            if ($this->is_featured == Status::YES) {
                $html = '<span class="badge badge--success">' . trans('Yes') . '</span>';
            } else {
                $html = '<span class="badge badge--warning">' . trans('No') . '</span>';
            }
            return $html;
        });
    }
}
