<?php

namespace App\Models;

use App\Constants\Status;
use App\Traits\GlobalStatus;
use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Model;

class Nft extends Model
{
    protected $casts = [
        'custom_data' => 'object',
    ];

    public function user()
    {
        return $this->belongsTo(User::class);
    }
    
    public function category()
    {
        return $this->belongsTo(Category::class);
    }

    public function items()
    {
        return $this->hasMany(Item::class);
    }

    public function nftActivities()
    {
        return $this->hasMany(NftActivity::class);
    }

    public function scopeBurned($query)
    {
        $query->where('status', Status::NFT_BURNED);
    }

    public function scopeActive($query)
    {
        $query->where('status', Status::NFT_ACTIVE);
    }

    public function scopeListed($query)
    {
        $query->where('status', Status::NFT_LISTED);
    }

    public function statusBadge(): Attribute
    {
        return new Attribute(function(){
            $html = '';
            if($this->status == Status::NFT_BURNED){
                $html = '<span class="badge badge--danger">'.trans('Burned').'</span>';
            }
            elseif($this->status == Status::NFT_ACTIVE){
                $html = '<span class="badge badge--primary">'.trans('Active').'</span>';
            }else{
                $html = '<span class="badge badge--success">'.trans('Listed').'</span>';
            }
            return $html;
        });
    }

}
