<?php

namespace App\Traits;

use App\Constants\Status;

trait UserNotify
{
    public static function notifyToUser()
    {
        return [
            'allUsers'                  => 'All Users',
            'selectedUsers'             => 'Selected Users',
            'kycUnverified'             => 'Kyc Unverified Users',
            'kycVerified'               => 'Kyc Verified Users',
            'kycPending'                => 'Kyc Pending Users',
            'hasDepositedUsers'         => 'Deposited Users',
            'notDepositedUsers'         => 'Not Deposited Users',
            'topDepositedUsers'         => 'Top Deposited Users',
            'hasWithdrawUsers'          => 'Withdraw Users',
            'notLoginUsers'             => 'Last Few Days Not Login Users',
            'pushNotificationActivated' => 'Push Notification Doesn\'t Activated Users',
            'hasFollowers'              => 'Has Followers',
            'nfts'                      => 'Users Who Has NFT',
            'items'                     => 'Users Who Has Items',
        ];
    }

    public function scopePushNotificationActivated($query)
    {
        return $query->whereDoesntHave('deviceTokens');
    }
    public function scopeFollowers($query)
    {
        return $query->whereHas('followers');
    }
    public function scopeHasFollowings($query)
    {
        return $query->whereHas('followings');
    }
    public function scopeNfts($query)
    {
        return $query->whereHas('nfts');
    }
    public function scopeItems($query)
    {
        return $query->whereHas('items');
    }
    public function scopeSelectedUsers($query)
    {
        return $query->whereIn('id', request()->user ?? []);
    }

    public function scopeAllUsers($query)
    {
        return $query;
    }


    public function scopeHasDepositedUsers($query)
    {
        return $query->whereHas('deposits');
    }

    public function scopeNotDepositedUsers($query)
    {
        return $query->whereDoesntHave('deposits');
    }

    public function scopeTopDepositedUsers($query)
    {
        return $query->whereHas('deposits')->withSum(['deposits'], 'amount')->orderBy('deposits_sum_amount', 'desc')->take(request()->number_of_top_deposited_user ?? 10);
    }

    public function scopeHasWithdrawUsers($query)
    {
        return $query->whereHas('withdrawals');
    }
    public function scopeNotLoginUsers($query)
    {
        return $query->whereDoesntHave('loginLogs', function ($q) {
            $q->whereDate('created_at', '>=', now()->subDays(request()->number_of_days ?? 10));
        });
    }

    public function scopeKycVerified($query)
    {
        return $query->where('kv', Status::KYC_VERIFIED);
    }
}
