@extends('admin.layouts.app')

@section('panel')
    <div class="row">
        <div class="col-md-12">
            <div class="card table-dropdown-solved b-radius--10 ">
                <div class="card-body p-0">
                    <div class="table-responsive--lg table-responsive">
                        <table class="table table--light style--two custom-data-table">
                            <thead>
                                <tr>
                                    <th>@lang('S.N.')</th>
                                    <th>@lang('Name')</th>
                                    <th>@lang('Category')</th>
                                    <th>@lang('Price')</th>
                                    <th>@lang('Featured')</th>
                                    <th>@lang('Status')</th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse ($items as $item)
                                    <tr>
                                        <td>{{ $loop->index + $items->firstItem() }}</td>
                                        <td>{{ __($item->nft->name) }}</td>
                                        <td>{{ __($item->nft->category->name) }}</td>
                                        <td>{{ showAmount($item->amount, 8, exceptZeros: true) }} {{ marketplaceCurrency() }}</td>
                                        <td>@php echo $item->featuredBadge; @endphp</td>
                                        <td>@php echo $item->statusBadge; @endphp</td>
                                        <td>
                                            <div class="button--group">
                                                <a href="{{ route('admin.item.detail', $item->id) }}" class="btn btn-sm btn-outline--primary">
                                                    <i class="la la-desktop"></i>@lang('Details')
                                                </a>

                                                <button type="button" class="btn btn-sm btn-outline--info" data-bs-toggle="dropdown" aria-expanded="false">
                                                    <i class="las la-ellipsis-v"></i>@lang('More')
                                                </button>

                                                <div class="dropdown-menu more-dropdown">
                                                    @if ($item->is_featured)
                                                        <button class="dropdown-item confirmationBtn" data-question="@lang('Are you sure to unfeatured this item?')" data-action="{{ route('admin.item.feature', $item->id) }}">
                                                            <i class="la la-highlighter"></i> @lang('Unfeatured')
                                                        </button>
                                                    @elseif(!$item->is_featured)
                                                        <button class="dropdown-item confirmationBtn" data-question="@lang('Are you sure to featured this item?')" data-action="{{ route('admin.item.feature', $item->id) }}">
                                                            <i class="la la-highlighter"></i> @lang('Featured')
                                                        </button>
                                                    @endif
                                                    @if ($item->is_auction && Carbon\Carbon::parse($item->auction_end_at) <= now())
                                                        <button class="dropdown-item makeWinner" data-item_id="{{ $item->itemId }}">
                                                            <i class="las la-trophy"></i> @lang('Make Winner')
                                                        </button>
                                                    @endif
                                                </div>
                                            </div>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
                @if ($items->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($items) }}
                    </div>
                @endif
            </div>
        </div>
    </div>

    <x-confirmation-modal />

    <div class="modal fade" id="makeWinnerModal" role="dialog" aria-hidden="true" tabindex="-1">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="modalTitleId">@lang('Confirmation Alert!')</h5>
                    <button class="btn-close" data-bs-dismiss="modal" type="button" aria-label="Close"></button>
                </div>
                <form class="makeWinnerForm" action="#">
                    <div class="modal-body">
                        <p>@lang('Are you sure to make winner of this item?')</p>
                        <input class="form-control form--control" name="item_id" type="hidden" required />
                    </div>
                    <div class="modal-footer">
                        <button class="btn btn--dark" data-bs-dismiss="modal" type="button">@lang('No')</button>
                        <button class="btn btn--primary" type="submit">@lang('Yes')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('breadcrumb-plugins')
    <x-search-form placeholder="Nft Name" />
@endpush



@push('script-lib')
    <script src="{{ asset('assets/global/js/web3.min.js') }}"></script>
    <script src="{{ asset('assets/global/js/ethers.min.js') }}"></script>
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";

            let
                provider = new ethers.providers.Web3Provider(window.ethereum),
                marketPlaceContract = `{{ $marketplace->contract }}`,
                marketPlaceAbi = null,
                reloadNow = (sleepTime = 2000) => {
                    setTimeout(() => {
                        window.location.reload(true)
                    }, sleepTime);
                },
                handleError = (error) => {
                    var message = error?.message ?? error?.data?.message;
                    if (error.code === 4001) {
                        notify('error', 'The request was rejected by the user')
                    } else if (error.code === -32602) {
                        notify('error', 'The parameters were invalid')
                    } else if (error.code === -32603) {
                        message || notify('error', 'Internal error')
                    } else {
                        console.error(error);
                    }
                    if (message) notify('error', 'Metamask: '.message);
                    reloadNow(5000);
                };

            $.getJSON(`{{ asset('assets/contracts/marketplace/abi.json') }}`, function(abi) {
                marketPlaceAbi = abi;
            });

            $('.makeWinner').on('click', function() {
                let modal = $('#makeWinnerModal');
                modal.find('[name=item_id]').val($(this).data('item_id'));
                modal.modal('show');
            });

            $('.makeWinnerForm').on('submit', async function(e) {
                e.preventDefault();
                let itemId = $(this).find('[name="item_id"]').val();
                await provider.send("eth_requestAccounts", []);
                const signer = provider.getSigner();
                const marketplace = new ethers.Contract(marketPlaceContract, marketPlaceAbi, signer);
                await (await marketplace.makeWinner(itemId).catch(handleError)).wait();

                $.ajax({
                    type: "GET",
                    url: `{{ route('admin.item.winner.notify', '') }}/${itemId}`,
                    success: function(response) {

                    }
                });

                reloadNow();
            });

        })(jQuery);
    </script>
@endpush
