@extends('admin.layouts.app')
@section('panel')
    <div class="row mb-none-30 justify-content-center">
        <div class="col-xl-4 col-md-6 mb-30">
            <div class="card b-radius--10 box--shadow1 overflow-hidden">
                <div class="card-body">
                    <h5 class="text-muted mb-20">{{ __($nft->name) }}</h5>
                    <ul class="list-group">
                        <li class="list-group-item d-flex justify-content-between align-items-center">
                            @lang('Category')
                            <span class="fw-bold">{{ __($nft->category->name) }}</span>
                        </li>
                        <li class="list-group-item d-flex justify-content-between align-items-center">
                            @lang('Transaction Hash')
                            <span class="fw-bold"><a href="{{ blockExplorer() }}/tx/{{ @$nft->transaction_hash }}" target="_blank">{{ showAddress($nft->transaction_hash) }}</a></span>
                        </li>
                        <li class="list-group-item d-flex justify-content-between align-items-center">
                            @lang('Contract Address')
                            <span class="fw-bold"><a href="{{ blockExplorer() }}/address/{{ @$nft->contract_address }}" target="_blank">{{ showAddress($nft->contract_address) }}</a></span>
                        </li>
                        <li class="list-group-item d-flex justify-content-between align-items-center">
                            @lang('Token Id')
                            <span class="fw-bold">{{ $nft->token_id }}</span>
                        </li>
                        <li class="list-group-item d-flex justify-content-between align-items-center">
                            @lang('Chain')
                            <span class="fw-bold">{{ __($nft->chain) }}</span>
                        </li>
                        <li class="list-group-item d-flex justify-content-between align-items-center">
                            @lang('Status')
                            @php echo $nft->statusBadge @endphp
                        </li>

                        @if (count(collect($nft->custom_data)))
                            <p class="mb-1 mt-2">@lang('Custom Field')</p>
                            @foreach ($nft->custom_data as $key => $value)
                                <li class="list-group-item d-flex justify-content-between align-items-center">
                                    {{ __(keyToTitle($key)) }}
                                    <span>{{ __($value) }}</span>
                                </li>
                            @endforeach
                        @endif
                    </ul>
                    <div class="mt-3">
                        <p>@lang('File')</p>
                        @if ($nft->file_type == 'audio')
                            <audio controls>
                                <source src="{{ $nft->file }}">
                            </audio>
                        @elseif($nft->file_type == 'video')
                            <video controls width="100%">
                                <source src="{{ $nft->file }}">
                            </video>
                        @elseif($nft->animation)
                            <img src="{{ $nft->animation }}">
                        @else
                            <img class="lazy" data-src="{{ $nft->file }}">
                        @endif
                    </div>
                </div>
            </div>
        </div>

        <div class="col-xl-8 col-md-6 mb-30">
            <div class="card b-radius--10 box--shadow1 overflow-hidden">
                <div class="card-body">
                    <h5 class="card-title border-bottom pb-2">@lang('Nft Activities')</h5>

                    <div class="table-responsive--md table-responsive">
                        <table class="table--light style--two table">
                            <thead>
                                <tr>
                                    <th>@lang('Event')</th>
                                    <th>@lang('Form')</th>
                                    <th>@lang('To')</th>
                                    <th>@lang('Date')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($nftActivities as $activity)
                                    <tr>
                                        <td>{{ __(ucFirst($activity->type)) }}</td>
                                        <td>
                                            @if ($activity->from_wallet)
                                                <a href="{{ route('admin.users.detail', [0, $activity->from_wallet]) }}">{{ showAddress($activity->from_wallet) }}</a>
                                            @else
                                                {{ showAddress($activity->from_wallet) }}
                                            @endif
                                        </td>
                                        <td>
                                            @if ($activity->to_wallet)
                                                <a href="{{ route('admin.users.detail', [0, $activity->to_wallet]) }}">{{ showAddress($activity->to_wallet) }}</a>
                                            @else
                                                {{ showAddress($activity->to_wallet) }}
                                            @endif
                                        </td>
                                        <td> <span class="text--base">{{ Carbon\Carbon::parse($activity->created_at)->diffForHumans() }}</span> </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse

                            </tbody>
                        </table><!-- table end -->
                    </div>
                    {{ paginateLinks($nftActivities) }}
                </div>
            </div>
        </div>

        @if (isset($item) && count($item->bids))
            <div class="card b-radius--10">
                <div class="card-body p-0">
                    <div class="table-responsive--md table-responsive">
                        <table class="table--light style--two table">
                            <thead>
                                <tr>
                                    <th>@lang('Price')</th>
                                    <th>@lang('Date')</th>
                                    <th>@lang('User')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($item->bids as $bid)
                                    <tr>
                                        <td>{{ showAmount($bid->amount, 8, exceptZeros: true) }} {{ marketplaceCurrency() }}</td>
                                        <td>{{ Carbon\Carbon::parse($bid->updated_at)->diffForHumans() }}</td>
                                        <td> <a href="{{ route('admin.users.detail', $bid->user->id) }}">{{ @$bid->user->username }}</a> </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table><!-- table end -->
                    </div>
                </div>
            </div>
        @endif
    </div>
@endsection
@push('script-lib')
    <script src="{{ asset('assets/global/js/jquery.lazy.min.js') }}"></script>
@endpush
@push('script')
    <script>
        (function($) {
            "use strict";
            $('.lazy').lazy({
                afterLoad: function(element) {
                    element.removeClass('lazy');
                }
            });
        })(jQuery)
    </script>
@endpush
@push('style')
    <style>
        img.lazy {
            width: 100%;
            display: block;
            background-image: url("{{ getImage('assets/images/loading.gif') }}");
            background-repeat: no-repeat;
            background-position: 50% 50%;
        }
    </style>
@endpush
