@extends('admin.layouts.app')

@section('panel')
    <div class="row">
        <div class="col-md-12">
            <div class="card b-radius--10 ">
                <div class="card-body p-0">
                    <div class="table-responsive--sm table-responsive">
                        <table class="table table--light style--two custom-data-table">
                            <thead>
                                <tr>
                                    <th>@lang('S.N.')</th>
                                    <th>@lang('Extension')</th>
                                    <th>@lang('File Type')</th>
                                    <th>@lang('Size')</th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse ($nftSizes as $nftSize)
                                    <tr>
                                        <td>{{ $loop->index + $nftSizes->firstItem() }}</td>
                                        <td>{{ $nftSize->file_extension }}</td>
                                        <td>{{ $nftSize->file_type }}</td>
                                        <td>{{ $nftSize->max_size }} @lang('KB')</td>
                                        <td>
                                            <div class="button--group">
                                                <button class="btn btn-sm btn-outline--primary editBtn" data-size="{{ $nftSize->max_size }}" data-extension="{{ $nftSize->file_extension }}" data-type="{{ $nftSize->file_type }}" data-action="{{ route('admin.nft.limit.update', $nftSize->id) }}">
                                                    <i class="la la-pencil"></i>@lang('Edit')
                                                </button>
                                            </div>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
                @if ($nftSizes->hasPages())
                    <div class="card-footer py-4">
                        {{ paginateLinks($nftSizes) }}
                    </div>
                @endif
            </div>
        </div>
    </div>

    {{-- NFT SIZE MODAL --}}
    <div id="nftSizeModal" class="modal fade" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Update NFT Size Limit')</h5>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form method="POST">
                    @csrf
                    <div class="modal-body">
                        <p>@lang('File Type:') <span class="fileType">@lang('image')</span></p>
                        <div class="form-group">
                            <label>@lang('Max Size for ') <span class="fileExtension"></span></label>
                            <div class="input-group">
                                <input type="number" min="1" name="max_size" class="form-control" required>
                                <span class="input-group-text">@lang('KB')</span>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn--primary w-100 h-45">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('breadcrumb-plugins')
    <x-search-form placeholder="File extension or Type" />
@endpush

@push('script')
    <script>
        (function($) {
            "use strict";
            $('.editBtn').on('click', function() {
                let modal = $('#nftSizeModal');
                let nftSize = $(this).data();
                modal.find('.fileExtension').text(nftSize.extension);
                modal.find('.fileType').text(nftSize.type);
                modal.find('[name=max_size]').val(nftSize.size);
                modal.find('form').attr('action', nftSize.action);
                modal.modal('show');
            });
        })(jQuery);
    </script>
@endpush
