@extends('admin.layouts.app')
@section('panel')
    <div class="row gy-4 mb-none-30">
        <div class="col-lg-6">
            <div class="card">
                <div class="card-header bg--primary d-flex justify-content-between">
                    <h5 class="text-white">@lang('Marketplace Contract')</h5>
                    @if (@$marketplace->contract)
                        <button class="btn btn-sm btn-danger float-end form-generate-btn confirmationBtn" data-action="{{ route('admin.contract.marketplace.destroy') }}" data-question="@lang('If you destroy the marketplace contract, the NFT contract, nfts, nfts activities, items, wishlists, bids, deposits and withdrawals will also be destroyed. Are you sure to destroy this contract?')" type="button"> <i class="la la-fw la-trash"></i>@lang('Destroy')</button>
                    @endif
                </div>
                <div class="card-body">
                    @if (@$marketplace->contract)
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group">
                                    <label>@lang('Contract Address')</label>
                                    <div class="input-group">
                                        <input class="form-control" value="{{ $marketplace->contract }}" readonly>
                                        <a class="input-group-text" href="{{ blockExplorer() }}/address/{{ $marketplace->contract }}" target="_blank">
                                            <i class="las la-external-link-alt"></i>
                                        </a>
                                    </div>
                                </div>
                                <div class="form-group">

                                    <div class="input-group">
                                        <input class="form-control" value="{{ $marketplace->txhash }}" readonly>
                                        <a class="input-group-text" href="{{ blockExplorer() }}/tx/{{ $marketplace->txhash }}" target="_blank">
                                            <i class="las la-external-link-alt"></i>
                                        </a>
                                    </div>
                                </div>
                                <div>
                                    <label> @lang('Contract info')</label>
                                    <ul class="list-group">
                                        <li class="list-group-item d-flex justify-content-between align-items-center">
                                            @lang('Trading Charge in percentage (%)')
                                            <span>{{ @marketplaceNetwork()->tradingCharge }}%</span>
                                        </li>
                                        <li
                                            class="list-group-item d-flex justify-content-between align-items-center">
                                            @lang('Deposit Charge in percentage (%)')
                                            <span>{{ @marketplaceNetwork()->depositCharge }}%</span>
                                        </li>
                                        <li
                                            class="list-group-item d-flex justify-content-between align-items-center">
                                            @lang('Withdrawal Charge in percentage (%)')
                                            <span>{{ @marketplaceNetwork()->withdrawalCharge }}%</span>
                                        </li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    @else
                        <form class="marketplaceContractForm" action="#" method="post">
                            <div class="row">
                                @foreach ($marketplace->parameters as $parameter => $input)
                                    <div class="col-md-12">
                                        <div class="form-group">
                                            <label>{{ __($input->label) }}</label>
                                            @if ($input->type == 'select')
                                                <select class="form-control" name="{{ $parameter }}" data-static="{{ @$input->is_static }}" required>
                                                    @foreach ($input->options as $key => $option)
                                                        <option value="{{ $key }}">{{ __(keyToTitle($option[0])) }}</option>
                                                    @endforeach
                                                </select>
                                            @else
                                                <input class="form-control" name="{{ $parameter }}" data-static="{{ @$input->is_static }}" type="{{ $input->type }}" required>
                                            @endif
                                        </div>
                                    </div>
                                @endforeach
                            </div>
                            <button class="btn btn--primary w-100 h-45" type="submit">
                                <i class="las la-cog"></i>
                                @lang('Deploy')
                            </button>
                        </form>
                    @endif
                </div>
            </div>
        </div>
        @if ($marketplace->contract)
            <div class="col-lg-6">
                <div class="card">
                    <div class="card-header bg--primary d-flex justify-content-between">
                        <h5 class="text-white">@lang('NFT Contract')</h5>
                        @if ($nft->contract)
                            <button class="btn btn-sm btn-danger float-end form-generate-btn confirmationBtn" data-action="{{ route('admin.contract.nft.destroy') }}" data-question="@lang('If you destroy the nft contract, the nfts, nfts activities, items, wishlists and bids will also be destroyed. Are you sure to destroy this contract?')" type="button"> <i class="la la-fw la-trash"></i>@lang('Destroy')</button>
                        @endif
                    </div>
                    <div class="card-body">
                        @if ($nft->contract)
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="form-group">
                                        <label>@lang('Contract Address')</label>
                                        <div class="input-group">
                                            <input class="form-control" value="{{ $nft->contract }}" readonly>
                                            <a class="input-group-text" href="{{ blockExplorer() }}/address/{{ $nft->contract }}" target="_blank">
                                                <i class="las la-external-link-alt"></i>
                                            </a>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <label>@lang('TX Hash')</label>
                                        <div class="input-group">
                                            <input class="form-control" value="{{ $nft->txhash }}" readonly>
                                            <a class="input-group-text" href="{{ blockExplorer() }}/tx/{{ $nft->txhash }}" target="_blank">
                                                <i class="las la-external-link-alt"></i>
                                            </a>
                                        </div>
                                    </div>
                                    <div>
                                        <label>@lang('Contract Info')</label>
                                        <ul class="list-group">
                                            <li class="list-group-item d-flex justify-content-between align-items-center">
                                                @lang('NFT Name')
                                                <span>{{ @myTokenName() }}</span>
                                            </li>
                                            <li class="list-group-item d-flex justify-content-between align-items-center">
                                                @lang('NFT Name')
                                                <span>{{ @myTokenSym() }}</span>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        @else
                            <form class="nftContractForm" action="#" method="post">
                                <div class="row">
                                    @foreach ($nft->parameters as $parameter => $input)
                                        <div class="col-md-12">
                                            <div class="form-group">
                                                <label>{{ __($input->label) }}</label>
                                                <input class="form-control" name="{{ $parameter }}" type="{{ $input->type }}" required>
                                            </div>
                                        </div>
                                    @endforeach
                                </div>
                                <button class="btn btn--primary w-100 h-45" type="submit">
                                    <i class="las la-cog"></i>
                                    @lang('Deploy')
                                </button>
                            </form>
                        @endif
                    </div>
                </div>
            </div>
        @endif

    </div>
    <x-confirmation-modal />

    <div class="modal fade" id="contractBalanceModal" role="dialog" tabindex="-1">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Alert')</h5>
                    <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                        <i class="las la-times"></i>
                    </button>
                </div>
                <form action="" method="POST">
                    @csrf
                    <div class="modal-body">
                        <div class="d-flex justify-content-between flex-wrap">
                            <p class="question">@lang('Contract Balance:')</p>
                            <p> <span class="balance"></span> <span>{{ marketplaceCurrency() }}</span></p>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button class="btn btn--dark" data-bs-dismiss="modal" type="button">@lang('Close')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('script-lib')
    <script src="{{ asset('assets/global/js/web3.min.js') }}"></script>
    <script src="{{ asset('assets/global/js/ethers.min.js') }}"></script>
@endpush

@push('script')
    <script>
        "use strict";
        (function($) {
            window.web3 = new Web3(window.ethereum);
            let account = null,
                marketPlaceAbi = null,
                marketplaceByteCode = null,
                marketplaceStoreRoute = `{{ route('admin.contract.marketplace.store') }}`,
                marketplaceParameters = @JSON($marketplace->parameters),
                nftAbi = null,
                formData = null,
                nftByteCode = null,
                nftStoreRoute = `{{ route('admin.contract.nft.store') }}`,
                nftParameters = @JSON($nft->parameters),
                nftContract = `{{ $nft->contract }}`,
                provider = new ethers.providers.Web3Provider(window.ethereum),
                marketPlaceContract = `{{ $marketplace->contract }}`,
                network = JSON.parse(`@json(marketplaceNetwork())`),
                reloadNow = (sleepTime = 2000) => {
                    setTimeout(() => {
                        window.location.reload(true)
                    }, sleepTime);
                },
                handleError = (error) => {
                    var message = error?.message ?? error?.data?.message;
                    if (error.code === 4001) {
                        notify('error', 'Metamask: The request was rejected by the user')
                    } else if (error.code === -32602) {
                        notify('error', 'Metamask: The parameters were invalid')
                    } else if (error.code === -32603) {
                        message || notify('error', 'Metamask: Internal error')
                    } else {
                        console.error(error);
                    }
                    if (message) notify('error', 'Metamask: ' + message);
                    reloadNow(5000);
                };
            $.getJSON(`{{ asset('assets/contracts/marketplace/abi.json') }}`, function(abi) {
                marketPlaceAbi = abi;
            });
            $.getJSON(`{{ asset('assets/contracts/marketplace/byte-code.json') }}`, function(byteCode) {
                marketplaceByteCode = byteCode.data;
            });
            $.getJSON(`{{ asset('assets/contracts/nft/abi.json') }}`, function(abi) {
                nftAbi = abi;
            });
            $.getJSON(`{{ asset('assets/contracts/nft/byte-code.json') }}`, function(byteCode) {
                nftByteCode = byteCode.data;
            });
            $('.marketplaceContractForm').on('submit', async function(e) {
                e.preventDefault();
                // detect wallet
                if (!window.ethereum) {
                    notify('error', 'MetaMask not detected. Please install MetaMask first.');
                    reloadNow();
                    return;
                }

                // check chain id

                let _chainId = await ethereum.request({
                    method: 'eth_chainId'
                });
                let chainId = $(this).find('[name=_network]').val();
                if (chainId != web3.utils.toDecimal(_chainId)) {
                    notify('error', 'Please select valid network in metamask');
                    return;
                }

                // get wallet address
                await window.ethereum.request({
                    method: 'eth_requestAccounts'
                });
                window.web3 = await new Web3(window.ethereum);
                account = (await web3.eth.getAccounts())[0];

                // process deployment
                let form = $(this);
                let parameters = [];
                formData = form.serializeArray();
                form.find(':submit').attr('disabled', true);
                $.each(marketplaceParameters, function(key, value) {
                    if (!value.is_static) {
                        parameters.push(form.find(`[name=${key}]`).val());
                    }
                });
                await deployContractAddress(marketPlaceAbi, marketplaceByteCode, parameters, marketplaceStoreRoute);

            });
            $('.nftContractForm').on('submit', async function(e) {
                e.preventDefault();
                // detect wallet
                if (!window.ethereum) {
                    notify('error', 'MetaMask not detected. Please install MetaMask first.');
                    reloadNow();
                    return;
                }
                // check chain id
                let _chainId = await ethereum.request({
                    method: 'eth_chainId'
                });
                let chainId = network.chain;
                if (chainId != web3.utils.toDecimal(_chainId)) {
                    notify('error', 'Please select valid network in metamask');
                    notify('info', `Your marketplace network is ${network.name}`);
                    return;
                }
                // get wallet address
                await window.ethereum.request({
                    method: 'eth_requestAccounts'
                });
                window.web3 = await new Web3(window.ethereum);
                account = (await web3.eth.getAccounts())[0];

                // process deployment
                let parameters = [];
                let form = $(this);
                formData = form.serializeArray();
                form.find(':submit').attr('disabled', true);
                $.each(nftParameters, function(key, value) {
                    parameters.push(form.find(`[name=${key}]`).val());
                });
                await deployContractAddress(nftAbi, nftByteCode, parameters, nftStoreRoute);

            });

            async function deployContractAddress(abi, byteCode, parameters, storeRoute) {
                var contractAddress = null;
                var deployableContract = new web3.eth.Contract(abi);

                var gasEstimate = await deployableContract.deploy({
                        data: byteCode,
                        arguments: parameters
                    })
                    .estimateGas({
                        from: account
                    })
                    .catch(handleError);
                if (!gasEstimate) {
                    return;
                }
                const deploymentGas = parseInt(gasEstimate * 1.1); // Add 10% buffer
                var deployedContract = deployableContract.deploy({
                    data: byteCode,
                    arguments: parameters
                }).send({
                    from: account,
                    gas: deploymentGas
                }, async function(e, transactionHash) {
                    if (transactionHash) {
                        contractAddress = await getContractAddress(transactionHash, contractAddress);
                    } else {
                        notify("error", "Something is wrong");
                        reloadNow();
                    }
                }).catch(handleError);
                async function getContractAddress(transactionHash, contractAddress) {
                    await web3.eth.getTransactionReceipt(transactionHash)
                        .then(async receipt => {
                            if (receipt) {
                                contractAddress = receipt.contractAddress;

                                // store contract details
                                let response = await fetch(storeRoute, {
                                    method: 'POST',
                                    headers: {
                                        'Content-Type': 'application/json'
                                    },
                                    body: JSON.stringify({
                                        '_token': '{{ csrf_token() }}',
                                        'txhash': transactionHash,
                                        'contract': contractAddress,
                                        'form_data': formData
                                    })
                                });
                                response = await response.json();
                                notify(response.type, response.message);
                                // reload this page
                                reloadNow();
                            }
                        });
                    if (!contractAddress) {
                        getContractAddress(transactionHash, contractAddress);
                        return;
                    }
                }
            }
        })(jQuery);
    </script>
@endpush
