@extends('admin.layouts.app')
@section('panel')
    <div class="row">
        <div class="col-md-12">
            <div class="card b-radius--10">
                <div class="card-body p-0">
                    <div class="table-responsive--sm table-responsive">
                        <table class="table--light style--two table">
                            <thead>
                                <tr>
                                    <th>@lang('Name')</th>
                                    <th>@lang('Status')</th>
                                    <th>@lang('Action')</th>
                                </tr>
                            </thead>
                            <tbody>
                                @foreach ($apis as $api)
                                    <tr>
                                        <td>{{ __($api->name) }}</td>
                                        <td>
                                            @if ($api->is_default)
                                                <span class="badge badge--success">@lang('Default')</span>
                                            @else
                                                <span class="badge badge--dark">@lang('Not Default')</span>
                                            @endif
                                        </td>
                                        <td>
                                            <button class="btn btn-sm btn-outline--primary editApi ms-1" data-name="{{ $api->name }}" data-action="{{ route('admin.nft.api.update', $api->id) }}" data-credentials="{{ collect($api->credentials)->where('is_static', false)->toJson() }}" data-is_default="{{ $api->is_default }}" type="button">
                                                <i class="la la-pen"></i> @lang('Edit')
                                            </button>

                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table><!-- table end -->
                    </div>
                </div>
            </div><!-- card end -->
        </div>
    </div>

    <div class="modal fade" id="nftApi">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Update API')</h5>
                    <button class="btn-close" data-bs-dismiss="modal" type="button" aria-label="Close"></button>
                </div>
                <form action="" method="post">
                    @csrf
                    <div class="modal-body">
                        <div class="form-group">
                            <label>@lang('Name')</label>
                            <input class="form-control" name="name" type="text" required>
                        </div>
                        <div class="credentials"></div>
                        <div class="form-group mt-2">
                            <label for="inputName">@lang('Default API')</label>
                            <input name="is_default" data-width="100%" data-height="40px" data-onstyle="-success" data-offstyle="-danger" data-bs-toggle="toggle" data-on="@lang('SET')" data-off="@lang('UNSET')" type="checkbox">
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button class="btn btn--primary w-100 h-45" type="submit">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@push('script')
    <script>
        "use strict";
        (function($) {
            $('.editApi').on('click', function() {
                var data = $(this).data();
                var modal = $('#nftApi');
                var credentials = data.credentials;
                var html = '';
                $.each(credentials, function(index, value) {
                    html += `
                        <div class="form-group">
                            <label for="${index}">${index.replace('_',' ').toUpperCase()}</label>
                            <input class="form-control" id="${index}" name="credentials[${index}]" value="${value.value}" type="text" required>
                        </div>
                    `;
                });
                $('.credentials').html(html);
                modal.find('[name=name]').val(data.name);
                if (data.is_default == 1) {
                    modal.find('input[name=is_default]').bootstrapToggle('on');
                } else {
                    modal.find('input[name=is_default]').bootstrapToggle('off');
                }
                modal.find('form').attr('action', data.action);
                modal.modal('show');
            });
        })(jQuery);
    </script>
@endpush
