@php
    $footer = getContent('footer.content', true);
    $socialIcons = getContent('social_icon.element', orderById: true);
    $subscribe = getContent('subscribe.content', true);
    $policyPages = getContent('policy_pages.element', false, null, true);
    $liveBiddings = App\Models\Item::listed()
        ->with([
            'nft',
            'bids' => function ($bid) {
                $bid->orderBy('amount', 'desc');
            },
        ])
        ->withCount('bids')
        ->where('is_auction', Status::YES)
        ->whereHas('nft.category', function ($category) {
            $category->active();
        })
        ->orderBy('auction_end_at', 'asc')
        ->limit(2)
        ->get();
@endphp

<footer class="footer-area">
    <div class="pt-120 pb-60">
        <div class="container">

            @if (gs('multi_language'))
                @php
                    $language = App\Models\Language::all();
                @endphp
                <div class="footer-top d-flex align-items-center justify-content-between mb-5 flex-wrap gap-2">
                    <p class="description">{{ __($footer->data_values->subtitle_one) }}</p>
                    <div class="language_switcher">
                        @php
                            $language = App\Models\Language::all();
                            $selectLang = $language->where('code', config('app.locale'))->first();
                            $currentLang = session('lang') ? $language->where('code', session('lang'))->first() : $language->where('is_default', Status::YES)->first();
                        @endphp
                        <div class="language_switcher__caption">
                            <span class="icon">
                                <img src="{{ getImage(getFilePath('language') . '/' . $currentLang->image, getFileSize('language')) }}" alt="@lang('image')">
                            </span>
                            <span class="text"> {{ __(@$selectLang->name) }} </span>
                        </div>
                        <div class="language_switcher__list">
                            @foreach ($language as $item)
                                <div class="language_switcher__item @if (session('lang') == $item->code) selected @endif" data-value="{{ $item->code }}">
                                    <a class="thumb" href="{{ route('lang', $item->code) }}">
                                        <span class="icon">
                                            <img src="{{ getImage(getFilePath('language') . '/' . $item->image, getFileSize('language')) }}" alt="@lang('image')">
                                        </span>
                                        <span class="text"> {{ __($item->name) }}</span>
                                    </a>
                                </div>
                            @endforeach
                        </div>
                    </div>
                </div>
            @endif
            <div class="row gy-5">
                <div class="col-xl-3 col-md-4 col-sm-6">
                    <div class="footer-item">

                        <div class="footer-item__logo">
                            <a class="logo logo-dark" href="{{ route('home') }}"> <img src="{{siteLogo('dark')}}" alt=""></a>
                            <a class="logo logo-light" href="{{ route('home') }}"> <img src="{{siteLogo()}}" alt=""></a>
                        </div>

                        <p class="footer-item__desc">{{ __($footer->data_values->subtitle_two) }}</p>
                        <ul class="social-list">
                            @foreach ($socialIcons as $social)
                                <li class="social-list__item"><a class="social-list__link" href="{{ $social->data_values->url }}" target="_blank"> @php echo $social->data_values->social_icon; @endphp </a></li>
                            @endforeach
                        </ul>
                    </div>
                </div>
                <div class="col-xl-2 col-md-4 col-sm-6">
                    <div class="footer-item">
                        <h4 class="footer-item__title">@lang('Useful Link')</h4>
                        <ul class="footer-menu">
                            <li class="footer-menu__item"><a class="footer-menu__link" href="{{ route('marketplace') }}">@lang('All Items')</a></li>
                            <li class="footer-menu__item"><a class="footer-menu__link" href="{{ route('user.item.listed') }}">@lang('My Items')</a></li>
                            <li class="footer-menu__item"><a class="footer-menu__link" href="{{ route('user.nft.all') }}">@lang('My Nft')</a></li>
                            <li class="footer-menu__item"><a class="footer-menu__link" href="{{ route('user.nft.mint') }}">@lang('Create')</a></li>
                        </ul>
                    </div>
                </div>
                <div class="col-xl-2 col-md-4 col-sm-6">
                    <div class="footer-item">
                        <h4 class="footer-item__title">@lang('Site Links')</h4>
                        <ul class="footer-menu">
                            <li class="footer-menu__item"><a class="footer-menu__link" href="{{ route('marketplace') }}?status=auction">@lang('Live Auctions')</a></li>
                            <li class="footer-menu__item"><a class="footer-menu__link" href="{{ route('user.wishlist') }}">@lang('Wishlist')</a></li>
                            @foreach ($policyPages as $policy)
                                <li class="footer-menu__item"><a class="footer-menu__link" href="{{ route('policy.pages', @$policy->slug) }}">{{ __($policy->data_values->title) }}</a></li>
                            @endforeach
                        </ul>
                    </div>
                </div>
                <div class="col-xl-2 col-lg-4 col-md-6 col-sm-6">
                    <h4 class="footer-item__title">@lang('Live Bidding')</h4>
                    @foreach ($liveBiddings as $liveBidding)
                        <div class="latest-bidding">
                            <div class="latest-bidding__thumb">
                                <a href="{{ route('nft.details', [slug($liveBidding->nft->name), encrypt($liveBidding->nft->id)]) }}">
                                    @if ($liveBidding->nft->file_type == 'video' || $liveBidding->nft->file_type == 'audio')
                                        <img class="lazy" data-src="{{ $liveBidding->nft->animation }}">
                                    @else
                                        <img class="lazy" data-src="{{ $liveBidding->nft->file }}">
                                    @endif
                                </a>
                            </div>
                            <div class="latest-bidding__content">
                                <h6 class="latest-bidding__title"> <a href="{{ route('nft.details', [slug($liveBidding->nft->name), encrypt($liveBidding->nft->id)]) }}">{{ __($liveBidding->nft->name) }}</a></h6>
                                <span class="latest-bidding__desc">@lang('Total Bid') {{ $liveBidding->bids_count }}</span>
                                <span class="latest-bidding__eth text--base">
                                    @if ($liveBidding->bids_count)
                                        {{ showAmount(@$liveBidding->bids->first()->amount, 8, exceptZeros: true) }} {{ marketplaceCurrency() }}
                                    @else
                                        {{ showAmount($liveBidding->amount, 8, exceptZeros: true) }} {{ marketplaceCurrency() }}
                                    @endif
                                </span>
                            </div>
                        </div>
                    @endforeach
                </div>
                <div class="col-xl-3 col-lg-4 col-md-6">
                    <div class="footer-item">
                        <h4 class="footer-item__title">{{ __($subscribe->data_values->title) }}</h4>
                        <p class="footer-item__desc">{{ __($subscribe->data_values->subtitle) }}</p>
                        <form class="subscriber-form" id="subscribe" action="{{ route('subscribe') }}" method="post">
                            @csrf
                            <div class="input-group">
                                <input class="form--control form-control" name="email" type="email" placeholder="@lang('Email')" required>
                                <button class="input-group-text subscriber-form__btn btn btn--base" type="submit"><i class="las la-long-arrow-alt-right"></i></button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- Footer Top End-->

    <!-- bottom Footer -->
    <div class="bottom-footer section py-3">
        <div class="container">
            <div class="row gy-3">
                <div class="col-md-12 text-center">
                    <div class="bottom-footer__text"> &copy; {{ date('Y') }} <a class="text--base" href="{{ route('home') }}">{{ __(gs('site_name')) }}</a>. @lang('All Rights Reserved')</div>
                </div>
            </div>
        </div>
    </div>
</footer>

@push('script')
    <script>
        (function($) {
            "use strict";
            $(".langSel").on("change", function() {
                window.location.href = "{{ route('home') }}/change/" + $(this).val();
            });
            $('.language_switcher > .language_switcher__caption').on('click', function() {
                $(this).parent().toggleClass('open');
            });
            $(document).on('keyup', function(evt) {
                if ((evt.keyCode || evt.which) === 27) {
                    $('.language_switcher').removeClass('open');
                }
            });
            $(document).on('click', function(evt) {
                if ($(evt.target).closest(".language_switcher > .language_switcher__caption").length === 0) {
                    $('.language_switcher').removeClass('open');
                }
            });

            $('#subscribe').on('submit', function(e) {
                e.preventDefault();
                var data = $('#subscribe').serialize();
                $.ajax({
                    type: "POST",
                    url: "{{ route('subscribe') }}",
                    data: data,
                    success: function(response) {
                        if (response.status == 'success') {
                            notify('success', response.message);
                            $('#email').val('');
                        } else {
                            notify('error', response.message);
                        }
                    }
                });
            });

        })(jQuery);
    </script>
@endpush