@php
    $contracts = App\Models\Contract::latest()->get();
    $marketplace = $contracts->where('act', 'marketplace')->first();
    $marketplaceContract = @$marketplace->contract;
    $policyPages = getContent('policy_pages.element', false, null, true);
@endphp
<div class="wallet-sidebar">
    <!-- <div class="wallet-sidebar-top"> -->
    <div class="wallet-info">
        <div class="wallet-info__inner">
            <div class="wallet-info__icon">
                <i class="las la-user"></i>
            </div>
            <div class="wallet-info__content">
                <h4 class="wallet-info__title">@lang('My Account')</h4>
            </div>
        </div>
        <div class="wallet-sidebar__close">
            <button class="btn btn--icon btn--dark circle"><i class="las la-times"></i></button>
        </div>
    </div>
    <!-- </div> -->
    <div class="wallet-sidebar__content">
        @auth
            <div class="mb-3 ms-3">
                <p>@lang('Wallet')</p>
                <p class="user-wallet userWallet">{{ auth()->user()->wallet }}</p>
            </div>

            @if (auth()->user()->status)
                <div class="d-flex align-items-center displayBalance d-none flex-wrap gap-1 px-3">
                    <p>@lang('Balance: ')</p>
                    <p class="balance"> *** </p>
                </div>
                <div class="d-flex align-items-center mt-3 flex-wrap gap-2 px-3">
                    <button class="btn btn--base btn--xsm pill getBalance">@lang('Show Balance')</button>
                    <button class="btn btn--base btn--xsm pill hideBalance d-none">@lang('Hide Balance')</button>
                    <button class="btn btn--base btn--xsm pill customModal depositBtn">@lang('Deposit')</button>
                    <button class="btn btn--base btn--xsm pill customModal withdrawalBtn">@lang('Withdraw')</button>
                </div>
            @endif
        @else
            @php
                $myAccount = getContent('my_account.content', true);
            @endphp
            <div class="wallet-sidebar__desc">
                <span>@lang('If you don\'t have a wallet yet, you can select a provider and create one now.')</span>
                @if (gs('agree'))
                    <div class="mt-3">
                        @lang('By login to NFTLab, you\'re accepting the')
                        @foreach ($policyPages as $policy)
                            <a class="text--base text-decoration-underline" href="{{ route('policy.pages', $policy->slug) }}" target="_blank">{{ __($policy->data_values->title) }}</a>
                            @if (!$loop->last)
                                ,
                            @endif
                        @endforeach
                    </div>
                @endif
            </div>
            <ul class="wallet-list">
                <li class="wallet-list__item">
                    <button class="wallet-list__link enableEthereumButton"> <img src="{{ getImage('assets/images/frontend/my_account/' . $myAccount->data_values->metamask_image, '25x25') }}" alt=""> <span class="text">@lang('Login with Metamask')</span> </button>
                </li>
            </ul>
        @endauth
    </div>
</div>

<div class="custom-modal" id="depositModal">
    <button class="custom-modal__close" type="button"><i class="las la-times"></i></button>
    <div class="custom-modal__inner">
        <div class="custom-modal__box">
            <div class="custom-modal__header">
                <h3 class="custom-modal__title">@lang('Deposit Now')</h3>
            </div>
            <div class="custom-modal__form">
                <form class="depositForm" action="#">
                    <div class="form-group">
                        <label class="form--label">@lang('Amount')</label>
                        <div class="input-group">
                            <input class="form-control form--control bg-transparent" name="amount" type="number" step="any" required />
                            <span class="input-group-text">{{ marketplaceCurrency() }}</span>
                        </div>
                    </div>
                    <div class="form-group">
                        <button class="btn btn--base w-100" type="submit">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<div class="custom-modal" id="withdrawalModal">
    <button class="custom-modal__close" type="button"><i class="las la-times"></i></button>
    <div class="custom-modal__inner">
        <div class="custom-modal__box">
            <div class="custom-modal__header">
                <h3 class="custom-modal__title">@lang('Withdraw Now')</h3>
            </div>
            <div class="custom-modal__form">
                <form class="withdrawForm" action="#">
                    <div class="form-group">
                        <label class="form--label">@lang('Amount')</label>
                        <div class="input-group">
                            <input class="form-control form--control" name="amount" type="number" step="any" required />
                            <span class="input-group-text">{{ marketplaceCurrency() }}</span>
                        </div>
                    </div>
                    <div class="form-group">
                        <button class="btn btn--base w-100" type="submit">@lang('Submit')</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

@push('style')
    <style>

    </style>
@endpush

@if (auth()->check() && auth()->user()->status)
    @push('script')
        <script>
            "use strict";
            (function($) {
                let marketplaceAbi = null,
                    provider = new ethers.providers.Web3Provider(window.ethereum),
                    reloadNow = (sleepTime = 2000) => {
                        setTimeout(() => {
                            window.location.reload(true)
                        }, sleepTime);
                    },
                    handleError = (error) => {
                        var message = error?.message ?? error?.data?.message;
                        if (error.code === 4001) {
                            notify('error', 'The request was rejected by the user')
                        } else if (error.code === -32602) {
                            notify('error', 'The parameters were invalid')
                        } else if (error.code === -32603) {
                            message || notify('error', 'Internal error')
                        } else {
                            console.error(error);
                        }
                        if (message) notify('error', 'Metamask: '.message);
                        reloadNow(5000);
                    },
                    checkSigner = async (signer, user) => {
                        let signerAddress = await signer.getAddress(),
                            matched = signerAddress == user;
                        (matched) || notify('error', `@lang('Please connect and select valid wallet')`);
                        (matched) || reloadNow(5000);
                        return matched;
                    };
                $.getJSON(`{{ asset('assets/contracts/marketplace/abi.json') }}`, function(abi) {
                    marketplaceAbi = abi;
                });

                $('.getBalance').on('click', async function() {
                    let currency = `{{ marketplaceCurrency() }}`;
                    let currencyRate = `{{ gs('currency_rate') }}`;
                    const marketPlaceContract = `{{ $marketplaceContract }}`;
                    await provider.send("eth_requestAccounts", []);
                    const signer = provider.getSigner();
                    if (!(await checkSigner(signer, `{{ auth()->user()->wallet }}`))) return;
                    const marketplace = new ethers.Contract(marketPlaceContract, marketplaceAbi, signer);
                    const user = await marketplace.getUser().catch(handleError);
                    let balance = ethers.utils.formatEther(user.balance);
                    let convertedBalance = (balance * currencyRate);
                    $('.balance').text(ethers.utils.formatEther(user.balance) + ` ${currency} (${convertedBalance.toFixed(2)} {{ gs('cur_text') }})`);
                    $(this).text('Sync');
                    $('.hideBalance, .displayBalance').removeClass('d-none');
                });

                $('.hideBalance').on('click', function() {
                    $('.balance').text('***');
                    $('.getBalance').text(`@lang('Show Balance')`);
                    $(this).addClass('d-none');
                    $('.displayBalance').addClass('d-none');
                });

                $('.depositForm').on('submit', async function(e) {
                    e.preventDefault();
                    $(".confirmation-loader, .confirmation-loader-2").fadeIn(300);

                    let amount = $(this).find('[name="amount"]').val();
                    let amountInWei = ethers.utils.parseUnits(`${amount}`, "ether");
                    let priceJson = {
                        value: amountInWei
                    };
                    const marketPlaceContract = `{{ $marketplaceContract }}`;
                    await provider.send("eth_requestAccounts", []);
                    const signer = provider.getSigner();
                    if (!(await checkSigner(signer, `{{ auth()->user()->wallet }}`))) return;
                    const marketplace = new ethers.Contract(marketPlaceContract, marketplaceAbi, signer);
                    let response = await (await marketplace.depositNow(priceJson).catch(handleError)).wait();

                    let data = {
                        'transaction_hash': response.transactionHash,
                        'amount': amount
                    };

                    $.ajax({
                        headers: {
                            "X-CSRF-TOKEN": "{{ csrf_token() }}",
                        },
                        url: `{{ route('user.account.deposit.save') }}`,
                        method: "POST",
                        data: data,
                        async: false,
                        success: function(response) {
                            notify('success', 'Deposit successfully completed');
                            $(".confirmation-loader, .confirmation-loader-2").fadeOut(300);
                        }
                    });

                    reloadNow();
                });

                $('.withdrawForm').on('submit', async function(e) {
                    e.preventDefault();
                    $(".confirmation-loader, .confirmation-loader-2").fadeIn(300);
                    let amount = $(this).find('[name="amount"]').val();
                    let amountInWei = ethers.utils.parseUnits(`${amount}`, "ether");
                    const marketPlaceContract = `{{ $marketplaceContract }}`;
                    await provider.send("eth_requestAccounts", []);
                    const signer = provider.getSigner();
                    if (!(await checkSigner(signer, `{{ auth()->user()->wallet }}`))) return;
                    const marketplace = new ethers.Contract(marketPlaceContract, marketplaceAbi, signer);
                    let response = await (await marketplace.withdrawNow(amountInWei).catch(handleError)).wait();

                    let data = {
                        'transaction_hash': response.transactionHash,
                        amount
                    };

                    $.ajax({
                        headers: {
                            "X-CSRF-TOKEN": "{{ csrf_token() }}",
                        },
                        url: `{{ route('user.account.withdraw.save') }}`,
                        method: "POST",
                        data: data,
                        async: false,
                        success: function(response) {
                            notify('success', 'Withdraw successfully completed');
                            $(".confirmation-loader, .confirmation-loader-2").fadeOut(300);
                        }
                    });
                    reloadNow();
                });

                $('.userWallet').on('click', function() {
                    var text = $(this).text();
                    var temp = $('<input>');
                    $('body').append(temp);
                    temp.val(text).select();
                    document.execCommand('copy');
                    temp.remove();
                    notify('success', 'Copied !');
                });

            })(jQuery);
        </script>
    @endpush
@endif
