@php
    $nftCount = App\Models\Nft::where('user_id', $user->id)
        ->where('status', '!=', Status::NFT_BURNED)
        ->whereHas('category', function ($category) {
            $category->active();
        })
        ->count();
@endphp

<section class="profile-banner">
    <div class="profile-banner__bg">
        <img src="{{ getImage(getFilePath('userCover') . '/' . $user->cover_image, getFileSize('userCover'), 'cover') }}" alt="">
    </div>
    <div class="custom--container">
        <div class="profile-wrapper">
            <div class="profile-thumb">
                <input id="image_type" name="image_type" type="hidden" value="profile_image">
                <div class="avatar-upload">
                    <div class="avatar-preview">
                        <div class="backgroundImage" id="profileBg" style="background-image: url({{ getImage(getFilePath('userProfile') . '/' . $user->profile_image, getFileSize('userProfile'), avatar: 'profile') }});">
                        </div>
                    </div>
                </div>
            </div>
            <div class="profile-wrapper__inner">
                <!-- Left Content Start -->
                <div class="profile-content">
                    <h4 class="profile-content__username">
                        {{ $user->firstname ? $user->fullname : 'Unnamed' }}
                        {{ $user->username ? '@' . $user->username : '' }} <x-verified status="{{ $user->kv }}" /></h4>
                    <ul class="profile-user-info-list">
                        <li class="profile-user-info-list__item"> @lang('NFTs') <span class="text--base">{{ isset($nftCount) ? $nftCount : $nfts->count() }}</span> </li>
                        <li class="profile-user-info-list__item"> @lang('Joined') <span class="text--base"> {{ showDateTime($user->created_at, 'M Y') }}</span> </li>
                    </ul>
                </div>

                <!-- Middle Content Start -->
                <ul class="profile-info">
                    <a class="profile-info__link @if (request()->routeIs('profile.public')) active @endif" href="{{ route('profile.public', $user->wallet) }}">
                        <h4 class="profile-info__number">{{ $nftCount }}</h4>
                        <span class="profile-info__text">@lang('Total NFTs')</span>
                    </a>
                    <a class="profile-info__link @if (request()->routeIs('profile.follow') && request()->follow == 'following') active @endif" href="{{ route('profile.follow', [$user->wallet, 'following']) }}">
                        <h4 class="profile-info__number">{{ showFollowerCount($user->following_count) }}</h4>
                        <span class="profile-info__text">@lang('Following')</span>
                    </a>
                    <a class="profile-info__link @if (request()->routeIs('profile.follow') && request()->follow == 'follower') active @endif" href="{{ route('profile.follow', [$user->wallet, 'follower']) }}">
                        <h4 class="profile-info__number">{{ showFollowerCount($user->follower_count) }}</h4>
                        <span class="profile-info__text">@lang('Follower')</span>
                    </a>
                </ul>
                <!-- Right Content Start -->
                <div class="profile-right">
                    <div class="profile-right__socials">
                        <ul class="social-list transparent-bg">
                            @if ($user->facebook_username)
                                <li class="social-list__item"><a class="social-list__link" href="https://www.facebook.com/{{ $user->facebook_username }}" target="_blank"><i class="fab fa-facebook-f"></i></a> </li>
                            @endif
                            @if ($user->twitter_username)
                                <li class="social-list__item"><a class="social-list__link" href="https://www.twitter.com/{{ $user->twitter_username }}" target="_blank"> <i class="fab fa-twitter"></i></a></li>
                            @endif
                            @if ($user->instagram_username)
                                <li class="social-list__item"><a class="social-list__link" href="https://www.instagram.com/{{ $user->instagram_username }}" target="_blank"> <i class="fab fa-instagram"></i></a></li>
                            @endif
                            @if ($user->pinterest_username)
                                <li class="social-list__item"><a class="social-list__link" href="https://www.pinterest.com/{{ $user->pinterest_username }}" target="_blank"> <i class="fab fa-pinterest"></i></a></li>
                            @endif
                            @if ($user->linkedin_username)
                                <li class="social-list__item"><a class="social-list__link" href="https://www.linkedin.com/in/{{ $user->linkedin_username }}" target="_blank"><i class="fab fa-linkedin"></i></a> </li>
                            @endif
                            @if ($user->website_url)
                                <li class="social-list__item"><a class="social-list__link" href="{{ $user->website_url }}" target="_blank"><i class="fas fa-globe"></i></a> </li>
                            @endif
                        </ul>
                    </div>
                    <div class="profile-right__buttons">
                        @if (auth()->id() != $user->id)
                            @php
                                $isFollowed = $user->followers()->where('follower_id', auth()->id())->exists();
                            @endphp
                            <button class="profile-right__follow btn btn--base btn--xsm follow @if (!$isFollowed) outline @endif" data-user_id="{{ $user->id }}"><span class="text">
                                    @if ($isFollowed)
                                        @lang('Following')
                                    @else
                                        @lang('Follow')
                                    @endif
                                </span></button>
                        @endif

                        <div class="social_share nft-card__dots" tabindex="-1">
                            <button class="profile-right__share btn btn--dark nft-card__dots btn--icon circle d-block" type="button"><i class="fas fa-share-alt"></i></button>
                            <ul class="ellipsis-dropdown">
                                <li class="ellipsis-dropdown__item"><a class="ellipsis-dropdown__button" href="https://www.facebook.com/sharer/sharer.php?u={{ urlencode(url()->current()) }}" target="_blank"> <span class="social-icon"><i class="fab fa-facebook-f"></i> </span> @lang('Facebook')</a>
                                </li>

                                <li class="ellipsis-dropdown__item"><a class="ellipsis-dropdown__button" href="https://twitter.com/intent/tweet?text={{ __($user->firstname ? $user->fullname : showAddress($user->wallet)) }}&amp;url={{ urlencode(url()->current()) }}" target="_blank"> <span
                                              class="social-icon"><i class="fab fa-twitter"></i> </span> @lang('Twitter')</a></li>
                                <li class="ellipsis-dropdown__item"><a class="ellipsis-dropdown__button" href="http://www.linkedin.com/shareArticle?mini=true&amp;url={{ urlencode(url()->current()) }}&amp;title={{ __($user->firstname ? $user->fullname : showAddress($user->wallet)) }}&amp;summary=@lang('Public Profile')" target="_blank"> <span class="social-icon"><i class="fab fa-linkedin-in"></i> </span> @lang('Linkedin')</a></li>
                            </ul>
                        </div>
                        @if (auth()->id() != $user->id)
                            <div class="nft-card__dots" tabindex="-1">
                                <button class="profile-right__dots nft-card__dots btn btn--dark btn--icon circle" type="button"><i class="fas fa-ellipsis-h"></i></button>
                                <ul class="ellipsis-dropdown">
                                    <li class="ellipsis-dropdown__item"><button class="ellipsis-dropdown__button customModal reportBtn" type="button">@lang('Report')</button></li>
                                </ul>
                            </div>
                        @endif
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>
<!-- ================================ Profile Banner End ============================ -->
