@php
    $featureCreator = getContent('featured_creator.content', true);
    $featuredUser = App\Models\User::with([
        'items' => function ($item) {
            $item
                ->listed()
                ->with('user', 'nft', 'bids.user')
                ->whereHas('nft.category', function ($category) {
                    $category->active();
                })
                ->orderBy('id', 'desc')
                ->limit(4);
        },
    ])
        ->withCount([
            'nfts' => function ($nft) {
                $nft->where('status', '!=', Status::NFT_BURNED)->whereHas('category', function ($category) {
                    $category->active();
                });
            },
        ])
        ->where('is_featured', 1)
        ->first();
@endphp

@if($featuredUser)
    <section class="featured pt-60 pb-60">
        <div class="container">
            <div class="section-heading">
                <h2 class="section-heading__title">{{ __(@$featureCreator->data_values->title) }}</h2>
            </div>
            <div class="featured-author-wrapper d-flex flex-wrap align-items-center justify-content-between gap-3">
                <div class="featured-author">
                    <div class="featured-author__thumb">
                        <img src="{{ getImage(getFilePath('userProfile').'/'. $featuredUser->profile_image, avatar:'profile') }}" alt="image">
                    </div>
                    <div class="featured-author__content">
                        <h5 class="featured-author__title">{{ $featuredUser->fullname }}   <x-verified status="{{ $featuredUser->kv }}" /></h5>
                        <span class="featured-author__date">@lang('Member Since') {{ Carbon\Carbon::parse($featuredUser->created_at)->format('F Y') }}</span>
                        <a href="{{ route('profile.public', $featuredUser->wallet) }}" class="btn btn--base btn--xsm">@lang('View Profile')</a>
                    </div>
                </div>
                <ul class="profile-info">
                    <a href="{{ route('profile.public', $featuredUser->wallet) }}" class="profile-info__link">
                        <h4 class="profile-info__number">{{ $featuredUser->nfts_count }}</h4>
                        <span class="profile-info__text">@lang('Total NFTs')</span>
                    </a>
                    <a href="{{ route('profile.follow', [$featuredUser->wallet, 'following']) }}" class="profile-info__link ">
                        <h4 class="profile-info__number">{{ showFollowerCount($featuredUser->following_count) }}</h4>
                        <span class="profile-info__text">@lang('Following')</span>
                    </a>
                    <a href="{{ route('profile.follow', [$featuredUser->wallet, 'follower']) }}" class="profile-info__link ">
                        <h4 class="profile-info__number">{{ showFollowerCount($featuredUser->follower_count) }}</h4>
                        <span class="profile-info__text">@lang('Follower')</span>
                    </a>
                </ul>
            </div>
            <div class="row gy-4 justify-content-center">
                @foreach ($featuredUser->items as $item)
                    <div class="col-xl-3 col-lg-4 col-sm-6 col-xsm-6">
                        @include($activeTemplate . 'partials.single_item', ['item' => $item])
                    </div>
                @endforeach
            </div>
        </div>
    </section>
@endif
