@php
    $topCreator = getContent('top_creator.content', true);
    $topCreators = App\Models\User::active()
        ->withCount([
            'nfts' => function ($nft) {
                $nft->where('status', '!=', Status::NFT_BURNED)->whereHas('category', function ($category) {
                    $category->active();
                });
            },
            'followers' => function ($follower) {
                $follower->where('follower_id', auth()->id());
            },
        ])
        ->whereHas('nfts')
        ->orderBy('nfts_count', 'desc')
        ->limit(4)
        ->get();
@endphp

@if ($topCreators->count())
    <section class="popular-creator pt-60 pb-120">
        <div class="container">
            <div class="section-heading">
                <h2 class="section-heading__title">{{ __($topCreator->data_values->title) }}</h2>
            </div>
            <div class="row gy-4 justify-content-center">
                @foreach ($topCreators as $creator)
                    <div class="col-xxl-3 col-sm-6 col-xsm-6">
                        <div class="creator-card">
                            <div class="creator-card__thumbs">
                                <img src="{{ getImage(getFilePath('userCover') . '/thumb_' . $creator->cover_image, null, 'cover') }}" alt="">
                            </div>
                            <div class="creator-card__content">
                                <div class="creator-card__creator">
                                    <img src="{{ getImage(getFilePath('userProfile') . '/' . $creator->profile_image, avatar: 'profile') }}" alt="">
                                </div>
                                <div class="creator-card__followers">
                                    <div class="creator-card__info">
                                        <h5 class="creator-card__title"> <a href="{{ route('profile.public', $creator->wallet) }}">{{ $creator->firstname ? $creator->fullname : showAddress($creator->wallet) }}   <x-verified status="{{ $creator->kv }}" /></a> </h5>
                                        <span class="creator-card__text"> <span class="followerCount">{{ showFollowerCount($creator->follower_count) }}</span> @lang('Followers')</span>
                                    </div>
                                    @if ($creator->id != auth()->id())
                                        @if ($creator->followers_count)
                                            <button type="button" class="creator-card__follow pill follow followed" data-user_id="{{ $creator->id }}">
                                                <span class="text">@lang('Following')</span>
                                            </button>
                                        @else
                                            <button type="button" class="creator-card__follow pill follow" data-user_id="{{ $creator->id }}">
                                                <span class="icon"><i class="las la-plus"></i></span>
                                                <span class="text">@lang('Follow')</span>
                                            </button>
                                        @endif
                                    @endif
                                    <ul class="creator-card__list profile-info ps-0 mt-2">
                                        <a href="{{ route('profile.public', $creator->wallet) }}" class="profile-info__link">
                                            <h5 class="profile-info__number">{{ $creator->nfts_count }}</h5>
                                            <span class="profile-info__text">@lang('Total NFTs')</span>
                                        </a>
                                        <a href="{{ route('profile.follow', [$creator->wallet, 'following']) }}" class="profile-info__link ">
                                            <h5 class="profile-info__number">{{ showFollowerCount($creator->following_count) }}</h5>
                                            <span class="profile-info__text">@lang('Following')</span>
                                        </a>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                @endforeach
            </div>
        </div>
    </section>
@endif
