<?php

use Illuminate\Support\Facades\Route;

Route::namespace('User\Auth')->name('user.')->group(function () {

    Route::middleware('guest')->group(function () {
        Route::controller('LoginController')->group(function () {
            Route::post('/web3/login', 'web3Login')->name('web3.login');
            Route::post('/web3/verify', 'web3Verify')->name('web3.verify');
            Route::get('logout', 'logout')->middleware('auth')->withoutMiddleware('guest')->name('logout');
        });
    });
});

Route::middleware('auth')->name('user.')->group(function () {
    //authorization
    Route::get('authorization', 'User\UserController@authorizeForm')->name('authorization');

    Route::middleware(['check.status'])->group(function () {
        Route::namespace('User')->group(function () {

            Route::controller('UserController')->group(function () {
                Route::get('download-attachments/{file_hash}', 'downloadAttachment')->name('download.attachment');
                Route::post('add-device-token', 'addDeviceToken')->name('add.device.token');
                Route::get('wishlist', 'wishlist')->name('wishlist');
                Route::get('follower', 'follower')->name('follower');
                Route::get('following', 'following')->name('following');

                Route::post('email/opt/send', 'sendEmailOtp')->name('email.otp.send');
                Route::post('email/opt/verify', 'verifyOtp')->name('otp.verify');
                Route::post('mobile/opt/send', 'sendMobileOtp')->name('mobile.otp.send');

                //KYC
                Route::get('kyc-form', 'kycForm')->name('kyc.form');
                Route::get('kyc-data', 'kycData')->name('kyc.data');
                Route::post('kyc-submit', 'kycSubmit')->name('kyc.submit');
            });

            //NFT
            Route::controller('NftController')->name('nft.')->prefix('nft')->group(function () {
                Route::get('mint', 'mintForm')->name('mint');
                Route::post('ipfs-url', 'uploadToIpfs')->name('ipfs.url');
                Route::post('mint/store', 'storeMint')->name('mint.store');

                Route::get('all', 'all')->name('all');
                Route::get('active', 'active')->name('active');
                Route::get('listed', 'listed')->name('listed');
                Route::get('burned', 'burned')->name('burned');

                Route::post('sell/list', 'storeList')->name('sell.list');
                Route::post('burn/{id}', 'burnNft')->name('burn');

                Route::post('meta-info-save', 'saveMetaInfo')->name('meta.info.save');
                Route::post('load-statistics', 'loadStatistics')->name('statistics.load');
            });
            // marketplace
            Route::controller('ItemController')->name('marketplace.')->prefix('marketplace')->group(function () {
                Route::post('unlist/{id}', 'unlistItem')->name('unlist');
                Route::get('detail/{id}', 'detail')->name('detail');
                Route::post('purchased/{id}', 'purchased')->name('purchased');
                Route::post('bid/now/{id}', 'bidNow')->name('bid.now');
                Route::post('bid/update/{id}', 'bidUpdate')->name('bid.update');
                Route::post('bid/claim/{id}', 'bidClaim')->name('bid.claim');
            });

            Route::controller('ItemController')->prefix('listings')->name('item.')->group(function () {
                Route::get('/', 'listed')->name('listed');
                Route::get('unlisted', 'unlisted')->name('unlisted');
                Route::get('sold', 'sold')->name('sold');
                Route::get('unclaim/bid', 'unclaimBid')->name('unclaim.bid');
            });

            // account
            Route::controller('AccountController')->name('account.')->prefix('account')->group(function () {
                Route::any('deposit/history', 'depositHistory')->name('deposit.history');
                Route::post('deposit/save', 'saveDeposit')->name('deposit.save');

                Route::get('withdraw/history', 'withdrawHistory')->name('withdraw.history');
                Route::post('withdraw/save', 'saveWithdraw')->name('withdraw.save');
            });
            //Profile setting
            Route::controller('ProfileController')->group(function () {
                Route::get('profile-setting', 'profileSetting')->name('profile.setting');
                Route::post('profile-setting', 'submitProfile');
                Route::post('save-image', 'saveImage')->name('image.save');
                Route::post('profile/report', 'reportProfile')->name('profile.report');
            });

            // Withdraw
            Route::controller('WithdrawController')->prefix('withdraw')->name('withdraw')->group(function () {
                Route::middleware('kyc')->group(function () {
                    Route::get('/', 'withdrawMoney');
                    Route::post('/', 'withdrawStore')->name('.money');
                    Route::get('preview', 'withdrawPreview')->name('.preview');
                    Route::post('preview', 'withdrawSubmit')->name('.submit');
                });
                Route::get('history', 'withdrawLog')->name('.history');
            });
        });
    });
});
